@@ -19,11 +19,15 @@ package config
 import (
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
 	gcetpm "k8s.io/kops/upup/pkg/fi/cloudup/gce/tpm"
+	"k8s.io/kops/upup/pkg/fi/cloudup/hetzner"
+	"k8s.io/kops/upup/pkg/fi/cloudup/openstack"
 )
 
 type Options struct {
+	ClusterName           string         `json:"clusterName,omitempty"`
 	Cloud                 string         `json:"cloud,omitempty"`
 	ConfigBase            string         `json:"configBase,omitempty"`
+	SecretStore           string         `json:"secretStore,omitempty"`
 	Server                *ServerOptions `json:"server,omitempty"`
 	CacheNodeidentityInfo bool           `json:"cacheNodeidentityInfo,omitempty"`
 
@@ -61,8 +65,10 @@ type ServerOptions struct {
 }
 
 type ServerProviderOptions struct {
-	AWS *awsup.AWSVerifierOptions  `json:"aws,omitempty"`
-	GCE *gcetpm.TPMVerifierOptions `json:"gce,omitempty"`
+	AWS       *awsup.AWSVerifierOptions           `json:"aws,omitempty"`
+	GCE       *gcetpm.TPMVerifierOptions          `json:"gce,omitempty"`
+	Hetzner   *hetzner.HetznerVerifierOptions     `json:"hetzner,omitempty"`
+	OpenStack *openstack.OpenStackVerifierOptions `json:"openstack,omitempty"`
 }
 
 // DiscoveryOptions configures our support for discovery, particularly gossip DNS (i.e. k8s.local)
