@@ -63,7 +63,7 @@ var (
 	    An InstanceGroup is a group of similar virtual machines.
 		On AWS, an InstanceGroup maps to an AutoScalingGroup.
 
-		The Role of an InstanceGroup defines whether machines will act as a Kubernetes master or node.`))
+		The Role of an InstanceGroup defines whether machines will act as a Kubernetes control-plane, or worker node.`))
 
 	createInstanceGroupExample = templates.Examples(i18n.T(`
 
@@ -82,7 +82,7 @@ var (
 // NewCmdCreateInstanceGroup create a new cobra command object for creating a instancegroup.
 func NewCmdCreateInstanceGroup(f *util.Factory, out io.Writer) *cobra.Command {
 	options := &CreateInstanceGroupOptions{
-		Role: string(kopsapi.InstanceGroupRoleNode),
+		Role: kopsapi.InstanceGroupRoleNode.ToLowerString(),
 		Edit: true,
 	}
 
@@ -119,7 +119,7 @@ func NewCmdCreateInstanceGroup(f *util.Factory, out io.Writer) *cobra.Command {
 			return nil, cobra.ShellCompDirectiveNoFileComp
 		},
 		RunE: func(cmd *cobra.Command, args []string) error {
-			return RunCreateInstanceGroup(context.TODO(), f, out, options)
+			return RunCreateInstanceGroup(cmd.Context(), f, out, options)
 		},
 	}
 
@@ -128,7 +128,7 @@ func NewCmdCreateInstanceGroup(f *util.Factory, out io.Writer) *cobra.Command {
 		if r == kopsapi.InstanceGroupRoleAPIServer && !featureflag.APIServerNodes.Enabled() {
 			continue
 		}
-		allRoles = append(allRoles, strings.ToLower(string(r)))
+		allRoles = append(allRoles, r.ToLowerString())
 	}
 
 	cmd.Flags().StringVar(&options.Role, "role", options.Role, "Type of instance group to create ("+strings.Join(allRoles, ",")+")")
@@ -277,8 +277,9 @@ func RunCreateInstanceGroup(ctx context.Context, f *util.Factory, out io.Writer,
 
 func completeClusterSubnet(f commandutils.Factory, excludeSubnets *[]string) func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	return func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		ctx := cmd.Context()
+
 		commandutils.ConfigureKlogForCompletion()
-		ctx := context.TODO()
 
 		cluster, _, completions, directive := GetClusterForCompletion(ctx, f, nil)
 		if cluster == nil {
@@ -292,12 +293,12 @@ func completeClusterSubnet(f commandutils.Factory, excludeSubnets *[]string) fun
 		var requiredType kopsapi.SubnetType
 		var subnets []string
 		alreadySelected := sets.NewString(*excludeSubnets...)
-		for _, subnet := range cluster.Spec.Subnets {
+		for _, subnet := range cluster.Spec.Networking.Subnets {
 			if alreadySelected.Has(subnet.Name) {
 				requiredType = subnet.Type
 			}
 		}
-		for _, subnet := range cluster.Spec.Subnets {
+		for _, subnet := range cluster.Spec.Networking.Subnets {
 			if !alreadySelected.Has(subnet.Name) && subnet.Type != kopsapi.SubnetTypeUtility &&
 				(subnet.Type == requiredType || requiredType == "") {
 				subnets = append(subnets, subnet.Name)
