@@ -19,11 +19,11 @@ package model
 import (
 	"encoding/json"
 	"fmt"
-	"os"
 	"strings"
 
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/kops/upup/pkg/fi/cloudup/openstack"
 	"k8s.io/kops/upup/pkg/fi/nodeup/nodetasks"
 )
 
@@ -70,9 +70,9 @@ type CloudConfigBuilder struct {
 	*NodeupModelContext
 }
 
-var _ fi.ModelBuilder = &CloudConfigBuilder{}
+var _ fi.NodeupModelBuilder = &CloudConfigBuilder{}
 
-func (b *CloudConfigBuilder) Build(c *fi.ModelBuilderContext) error {
+func (b *CloudConfigBuilder) Build(c *fi.NodeupModelBuilderContext) error {
 	if err := b.build(c, true); err != nil {
 		return err
 	}
@@ -82,7 +82,7 @@ func (b *CloudConfigBuilder) Build(c *fi.ModelBuilderContext) error {
 	return nil
 }
 
-func (b *CloudConfigBuilder) build(c *fi.ModelBuilderContext, inTree bool) error {
+func (b *CloudConfigBuilder) build(c *fi.NodeupModelBuilderContext, inTree bool) error {
 	// Add cloud config file if needed
 	var lines []string
 
@@ -123,100 +123,14 @@ func (b *CloudConfigBuilder) build(c *fi.ModelBuilderContext, inTree bool) error
 		if osc == nil {
 			break
 		}
-		// Support mapping of older keystone API
-		tenantName := os.Getenv("OS_TENANT_NAME")
-		if tenantName == "" {
-			tenantName = os.Getenv("OS_PROJECT_NAME")
-		}
-		tenantID := os.Getenv("OS_TENANT_ID")
-		if tenantID == "" {
-			tenantID = os.Getenv("OS_PROJECT_ID")
-		}
-		lines = append(lines,
-			fmt.Sprintf("auth-url=\"%s\"", os.Getenv("OS_AUTH_URL")),
-			fmt.Sprintf("username=\"%s\"", os.Getenv("OS_USERNAME")),
-			fmt.Sprintf("password=\"%s\"", os.Getenv("OS_PASSWORD")),
-			fmt.Sprintf("region=\"%s\"", os.Getenv("OS_REGION_NAME")),
-			fmt.Sprintf("tenant-id=\"%s\"", tenantID),
-			fmt.Sprintf("tenant-name=\"%s\"", tenantName),
-			fmt.Sprintf("domain-name=\"%s\"", os.Getenv("OS_DOMAIN_NAME")),
-			fmt.Sprintf("domain-id=\"%s\"", os.Getenv("OS_DOMAIN_ID")),
-		)
-		if b.Cluster.Spec.ExternalCloudControllerManager != nil {
-			lines = append(lines,
-				fmt.Sprintf("application-credential-id=\"%s\"", os.Getenv("OS_APPLICATION_CREDENTIAL_ID")),
-				fmt.Sprintf("application-credential-secret=\"%s\"", os.Getenv("OS_APPLICATION_CREDENTIAL_SECRET")),
-			)
-		}
 
-		lines = append(lines,
-			"",
-		)
+		lines = append(lines, openstack.MakeCloudConfig(b.Cluster.Spec)...)
 
-		if lb := osc.Loadbalancer; lb != nil {
-			ingressHostnameSuffix := "nip.io"
-			if fi.StringValue(lb.IngressHostnameSuffix) != "" {
-				ingressHostnameSuffix = fi.StringValue(lb.IngressHostnameSuffix)
-			}
-
-			lines = append(lines,
-				"[LoadBalancer]",
-				fmt.Sprintf("floating-network-id=%s", fi.StringValue(lb.FloatingNetworkID)),
-				fmt.Sprintf("lb-method=%s", fi.StringValue(lb.Method)),
-				fmt.Sprintf("lb-provider=%s", fi.StringValue(lb.Provider)),
-				fmt.Sprintf("use-octavia=%t", fi.BoolValue(lb.UseOctavia)),
-				fmt.Sprintf("manage-security-groups=%t", fi.BoolValue(lb.ManageSecGroups)),
-				fmt.Sprintf("enable-ingress-hostname=%t", fi.BoolValue(lb.EnableIngressHostname)),
-				fmt.Sprintf("ingress-hostname-suffix=%s", ingressHostnameSuffix),
-				"",
-			)
-
-			if monitor := osc.Monitor; monitor != nil {
-				lines = append(lines,
-					"create-monitor=yes",
-					fmt.Sprintf("monitor-delay=%s", fi.StringValue(monitor.Delay)),
-					fmt.Sprintf("monitor-timeout=%s", fi.StringValue(monitor.Timeout)),
-					fmt.Sprintf("monitor-max-retries=%d", fi.IntValue(monitor.MaxRetries)),
-					"",
-				)
-			}
-		}
-
-		if bs := osc.BlockStorage; bs != nil {
-			// Block Storage Config
-			lines = append(lines,
-				"[BlockStorage]",
-				fmt.Sprintf("bs-version=%s", fi.StringValue(bs.Version)),
-				fmt.Sprintf("ignore-volume-az=%t", fi.BoolValue(bs.IgnoreAZ)),
-				"")
-		}
-
-		if networking := osc.Network; networking != nil {
-			// Networking Config
-			// https://github.com/kubernetes/cloud-provider-openstack/blob/master/docs/openstack-cloud-controller-manager/using-openstack-cloud-controller-manager.md#networking
-			var networkingLines []string
-
-			if networking.IPv6SupportDisabled != nil {
-				networkingLines = append(networkingLines, fmt.Sprintf("ipv6-support-disabled=%t", fi.BoolValue(networking.IPv6SupportDisabled)))
-			}
-			for _, name := range networking.PublicNetworkNames {
-				networkingLines = append(networkingLines, fmt.Sprintf("public-network-name=%s", fi.StringValue(name)))
-			}
-			for _, name := range networking.InternalNetworkNames {
-				networkingLines = append(networkingLines, fmt.Sprintf("internal-network-name=%s", fi.StringValue(name)))
-			}
-
-			if len(networkingLines) > 0 {
-				lines = append(lines, "[Networking]")
-				lines = append(lines, networkingLines...)
-				lines = append(lines, "")
-			}
-		}
 	case "azure":
 		requireGlobal = false
 
 		var region string
-		for _, subnet := range b.Cluster.Spec.Subnets {
+		for _, subnet := range b.Cluster.Spec.Networking.Subnets {
 			if subnet.Region != "" {
 				region = subnet.Region
 				break
@@ -226,7 +140,7 @@ func (b *CloudConfigBuilder) build(c *fi.ModelBuilderContext, inTree bool) error
 			return fmt.Errorf("on Azure, subnets must include Regions")
 		}
 
-		vnetName := b.Cluster.Spec.NetworkID
+		vnetName := b.Cluster.Spec.Networking.NetworkID
 		if vnetName == "" {
 			vnetName = b.Cluster.Name
 		}
