@@ -49,10 +49,10 @@ type KubeAPIServerBuilder struct {
 	*NodeupModelContext
 }
 
-var _ fi.ModelBuilder = &KubeAPIServerBuilder{}
+var _ fi.NodeupModelBuilder = &KubeAPIServerBuilder{}
 
 // Build is responsible for generating the configuration for the kube-apiserver.
-func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
+func (b *KubeAPIServerBuilder) Build(c *fi.NodeupModelBuilderContext) error {
 	if !b.HasAPIServer {
 		return nil
 	}
@@ -79,7 +79,7 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 	}
 
 	if b.NodeupConfig.APIServerConfig.EncryptionConfigSecretHash != "" {
-		encryptionConfigPath := fi.String(filepath.Join(pathSrvKAPI, "encryptionconfig.yaml"))
+		encryptionConfigPath := fi.PtrTo(filepath.Join(pathSrvKAPI, "encryptionconfig.yaml"))
 
 		kubeAPIServer.EncryptionProviderConfig = encryptionConfigPath
 
@@ -90,7 +90,7 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 			t := &nodetasks.File{
 				Path:     *encryptionConfigPath,
 				Contents: fi.NewStringResource(contents),
-				Mode:     fi.String("600"),
+				Mode:     fi.PtrTo("600"),
 				Type:     nodetasks.FileType_File,
 			}
 			c.AddTask(t)
@@ -121,7 +121,7 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 			Path:     filepath.Join(pathSrvKAPI, "etcd-ca.crt"),
 			Contents: fi.NewStringResource(b.NodeupConfig.CAs["etcd-clients-ca"]),
 			Type:     nodetasks.FileType_File,
-			Mode:     fi.String("0644"),
+			Mode:     fi.PtrTo("0644"),
 		})
 		kubeAPIServer.EtcdCAFile = filepath.Join(pathSrvKAPI, "etcd-ca.crt")
 
@@ -147,7 +147,7 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 			Path:     filepath.Join(pathSrvKAPI, "apiserver-aggregator-ca.crt"),
 			Contents: fi.NewStringResource(b.NodeupConfig.CAs["apiserver-aggregator-ca"]),
 			Type:     nodetasks.FileType_File,
-			Mode:     fi.String("0644"),
+			Mode:     fi.PtrTo("0644"),
 		})
 		kubeAPIServer.RequestheaderClientCAFile = filepath.Join(pathSrvKAPI, "apiserver-aggregator-ca.crt")
 
@@ -164,8 +164,8 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 		if err != nil {
 			return err
 		}
-		kubeAPIServer.ProxyClientCertFile = fi.String(filepath.Join(pathSrvKAPI, "apiserver-aggregator.crt"))
-		kubeAPIServer.ProxyClientKeyFile = fi.String(filepath.Join(pathSrvKAPI, "apiserver-aggregator.key"))
+		kubeAPIServer.ProxyClientCertFile = fi.PtrTo(filepath.Join(pathSrvKAPI, "apiserver-aggregator.crt"))
+		kubeAPIServer.ProxyClientKeyFile = fi.PtrTo(filepath.Join(pathSrvKAPI, "apiserver-aggregator.key"))
 	}
 
 	if err := b.writeServerCertificate(c, &kubeAPIServer); err != nil {
@@ -216,7 +216,7 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 	return nil
 }
 
-func (b *KubeAPIServerBuilder) writeAuthenticationConfig(c *fi.ModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
+func (b *KubeAPIServerBuilder) writeAuthenticationConfig(c *fi.NodeupModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
 	if b.Cluster.Spec.Authentication == nil || b.Cluster.Spec.Authentication.IsEmpty() {
 		return nil
 	}
@@ -263,7 +263,7 @@ func (b *KubeAPIServerBuilder) writeAuthenticationConfig(c *fi.ModelBuilderConte
 
 	if b.Cluster.Spec.Authentication.AWS != nil {
 		id := "aws-iam-authenticator"
-		kubeAPIServer.AuthenticationTokenWebhookConfigFile = fi.String(PathAuthnConfig)
+		kubeAPIServer.AuthenticationTokenWebhookConfigFile = fi.PtrTo(PathAuthnConfig)
 
 		{
 			cluster := kubeconfig.KubectlCluster{
@@ -298,7 +298,7 @@ func (b *KubeAPIServerBuilder) writeAuthenticationConfig(c *fi.ModelBuilderConte
 				Path:     PathAuthnConfig,
 				Contents: fi.NewBytesResource(manifest),
 				Type:     nodetasks.FileType_File,
-				Mode:     fi.String("600"),
+				Mode:     fi.PtrTo("600"),
 			})
 		}
 
@@ -333,18 +333,18 @@ func (b *KubeAPIServerBuilder) writeAuthenticationConfig(c *fi.ModelBuilderConte
 				Path:     "/srv/kubernetes/aws-iam-authenticator/cert.pem",
 				Contents: certificate,
 				Type:     nodetasks.FileType_File,
-				Mode:     fi.String("600"),
-				Owner:    fi.String("aws-iam-authenticator"),
-				Group:    fi.String("aws-iam-authenticator"),
+				Mode:     fi.PtrTo("600"),
+				Owner:    fi.PtrTo("aws-iam-authenticator"),
+				Group:    fi.PtrTo("aws-iam-authenticator"),
 			})
 
 			c.AddTask(&nodetasks.File{
 				Path:     "/srv/kubernetes/aws-iam-authenticator/key.pem",
 				Contents: privateKey,
 				Type:     nodetasks.FileType_File,
-				Mode:     fi.String("600"),
-				Owner:    fi.String("aws-iam-authenticator"),
-				Group:    fi.String("aws-iam-authenticator"),
+				Mode:     fi.PtrTo("600"),
+				Owner:    fi.PtrTo("aws-iam-authenticator"),
+				Group:    fi.PtrTo("aws-iam-authenticator"),
 			})
 		}
 
@@ -354,7 +354,7 @@ func (b *KubeAPIServerBuilder) writeAuthenticationConfig(c *fi.ModelBuilderConte
 	return fmt.Errorf("unrecognized authentication config %v", b.Cluster.Spec.Authentication)
 }
 
-func (b *KubeAPIServerBuilder) writeServerCertificate(c *fi.ModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
+func (b *KubeAPIServerBuilder) writeServerCertificate(c *fi.NodeupModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
 	pathSrvKAPI := filepath.Join(b.PathSrvKubernetes(), "kube-apiserver")
 
 	{
@@ -367,9 +367,11 @@ func (b *KubeAPIServerBuilder) writeServerCertificate(c *fi.ModelBuilderContext,
 		}
 
 		// Names specified in the cluster spec
-		alternateNames = append(alternateNames, b.Cluster.Spec.MasterPublicName)
-		alternateNames = append(alternateNames, b.Cluster.Spec.MasterInternalName)
-		alternateNames = append(alternateNames, b.Cluster.Spec.AdditionalSANs...)
+		if b.Cluster.Spec.API.PublicName != "" {
+			alternateNames = append(alternateNames, b.Cluster.Spec.API.PublicName)
+		}
+		alternateNames = append(alternateNames, b.Cluster.APIInternalName())
+		alternateNames = append(alternateNames, b.Cluster.Spec.API.AdditionalSANs...)
 
 		// Load balancer IPs passed in through NodeupConfig
 		alternateNames = append(alternateNames, b.NodeupConfig.ApiserverAdditionalIPs...)
@@ -396,7 +398,7 @@ func (b *KubeAPIServerBuilder) writeServerCertificate(c *fi.ModelBuilderContext,
 			}
 		}
 		if b.CloudProvider == kops.CloudProviderOpenstack {
-			if b.Cluster.Spec.Topology != nil && b.Cluster.Spec.Topology.Masters == kops.TopologyPrivate {
+			if b.Cluster.Spec.Networking.Topology != nil && b.Cluster.Spec.Networking.Topology.ControlPlane == kops.TopologyPrivate {
 				instanceAddress, err := getInstanceAddress()
 				if err != nil {
 					return err
@@ -434,7 +436,7 @@ func (b *KubeAPIServerBuilder) writeServerCertificate(c *fi.ModelBuilderContext,
 	return nil
 }
 
-func (b *KubeAPIServerBuilder) writeKubeletAPICertificate(c *fi.ModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
+func (b *KubeAPIServerBuilder) writeKubeletAPICertificate(c *fi.NodeupModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
 	pathSrvKAPI := filepath.Join(b.PathSrvKubernetes(), "kube-apiserver")
 
 	issueCert := &nodetasks.IssueCert{
@@ -457,7 +459,7 @@ func (b *KubeAPIServerBuilder) writeKubeletAPICertificate(c *fi.ModelBuilderCont
 	return nil
 }
 
-func (b *KubeAPIServerBuilder) writeStaticCredentials(c *fi.ModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
+func (b *KubeAPIServerBuilder) writeStaticCredentials(c *fi.NodeupModelBuilderContext, kubeAPIServer *kops.KubeAPIServerConfig) error {
 	pathSrvKAPI := filepath.Join(b.PathSrvKubernetes(), "kube-apiserver")
 
 	if b.SecretStore != nil {
@@ -510,8 +512,8 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 	// running on master nodes
 	if !b.IsMaster {
 		clusterName := b.Cluster.ObjectMeta.Name
-		mainEtcdDNSName := "main.etcd." + clusterName
-		eventsEtcdDNSName := "events.etcd." + clusterName
+		mainEtcdDNSName := "main.etcd.internal." + clusterName
+		eventsEtcdDNSName := "events.etcd.internal." + clusterName
 		for i := range kubeAPIServer.EtcdServers {
 			kubeAPIServer.EtcdServers[i] = strings.ReplaceAll(kubeAPIServer.EtcdServers[i], "127.0.0.1", mainEtcdDNSName)
 		}
@@ -542,10 +544,7 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 		return nil, fmt.Errorf("error building kube-apiserver flags: %v", err)
 	}
 
-	// add cloud config file if needed
-	if b.Cluster.Spec.CloudConfig != nil {
-		flags = append(flags, fmt.Sprintf("--cloud-config=%s", InTreeCloudConfigFilePath))
-	}
+	flags = append(flags, fmt.Sprintf("--cloud-config=%s", InTreeCloudConfigFilePath))
 
 	pod := &v1.Pod{
 		TypeMeta: metav1.TypeMeta{
@@ -573,7 +572,7 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 		Port: intstr.FromInt(wellknownports.KubeAPIServerHealthCheck),
 	}
 
-	insecurePort := fi.Int32Value(kubeAPIServer.InsecurePort)
+	insecurePort := fi.ValueOf(kubeAPIServer.InsecurePort)
 	if useHealthcheckProxy {
 		// kube-apiserver-healthcheck sidecar container runs on port 3990
 	} else if insecurePort != 0 {
@@ -605,9 +604,6 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 	}
 
 	image := kubeAPIServer.Image
-	if components.IsBaseURL(b.Cluster.Spec.KubernetesVersion) && b.IsKubernetesLT("1.25") {
-		image = strings.Replace(image, "registry.k8s.io", "k8s.gcr.io", 1)
-	}
 	if b.Architecture != architectures.ArchitectureAmd64 {
 		image = strings.Replace(image, "-amd64", "-"+string(b.Architecture), 1)
 	}
@@ -615,7 +611,7 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 	container := &v1.Container{
 		Name:  "kube-apiserver",
 		Image: image,
-		Env:   proxy.GetProxyEnvVars(b.Cluster.Spec.EgressProxy),
+		Env:   proxy.GetProxyEnvVars(b.Cluster.Spec.Networking.EgressProxy),
 		LivenessProbe: &v1.Probe{
 			ProbeHandler: v1.ProbeHandler{
 				HTTPGet: probeAction,
@@ -676,10 +672,7 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 		kubemanifest.AddHostPathMapping(pod, container, name, path)
 	}
 
-	// Add cloud config file if needed
-	if b.Cluster.Spec.CloudConfig != nil {
-		kubemanifest.AddHostPathMapping(pod, container, "cloudconfig", InTreeCloudConfigFilePath)
-	}
+	kubemanifest.AddHostPathMapping(pod, container, "cloudconfig", InTreeCloudConfigFilePath)
 
 	kubemanifest.AddHostPathMapping(pod, container, "kubernetesca", filepath.Join(b.PathSrvKubernetes(), "ca.crt"))
 
@@ -726,14 +719,16 @@ func (b *KubeAPIServerBuilder) buildAnnotations() map[string]string {
 	annotations := make(map[string]string)
 	annotations["kubectl.kubernetes.io/default-container"] = "kube-apiserver"
 
-	if b.Cluster.Spec.API != nil {
-		if b.Cluster.Spec.API.LoadBalancer == nil || !b.Cluster.Spec.API.LoadBalancer.UseForInternalAPI {
-			annotations["dns.alpha.kubernetes.io/internal"] = b.Cluster.Spec.MasterInternalName
-		}
+	if b.Cluster.UsesNoneDNS() {
+		return annotations
+	}
 
-		if b.Cluster.Spec.API.DNS != nil {
-			annotations["dns.alpha.kubernetes.io/external"] = b.Cluster.Spec.MasterPublicName
-		}
+	if b.Cluster.Spec.API.LoadBalancer == nil || !b.Cluster.Spec.API.LoadBalancer.UseForInternalAPI {
+		annotations["dns.alpha.kubernetes.io/internal"] = b.Cluster.APIInternalName()
+	}
+
+	if b.Cluster.Spec.API.DNS != nil && b.Cluster.Spec.API.PublicName != "" {
+		annotations["dns.alpha.kubernetes.io/external"] = b.Cluster.Spec.API.PublicName
 	}
 
 	return annotations
