@@ -28,14 +28,12 @@ import (
 	"github.com/aws/aws-sdk-go/aws/ec2metadata"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ec2"
-	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/serializer"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/flagbuilder"
 	"k8s.io/kops/pkg/model/components"
-	"k8s.io/kops/pkg/nodelabels"
 	"k8s.io/kops/pkg/rbac"
 	"k8s.io/kops/pkg/systemd"
 	"k8s.io/kops/upup/pkg/fi"
@@ -60,10 +58,10 @@ type KubeletBuilder struct {
 	*NodeupModelContext
 }
 
-var _ fi.ModelBuilder = &KubeletBuilder{}
+var _ fi.NodeupModelBuilder = &KubeletBuilder{}
 
 // Build is responsible for building the kubelet configuration
-func (b *KubeletBuilder) Build(c *fi.ModelBuilderContext) error {
+func (b *KubeletBuilder) Build(c *fi.NodeupModelBuilderContext) error {
 	err := b.buildKubeletServingCertificate(c)
 	if err != nil {
 		return fmt.Errorf("error building kubelet server cert: %v", err)
@@ -134,7 +132,7 @@ func (b *KubeletBuilder) Build(c *fi.ModelBuilderContext) error {
 		if b.HasAPIServer || !b.UseBootstrapTokens() {
 			var kubeconfig fi.Resource
 			if b.HasAPIServer {
-				kubeconfig, err = b.buildMasterKubeletKubeconfig(c)
+				kubeconfig, err = b.buildControlPlaneKubeletKubeconfig(c)
 			} else {
 				kubeconfig, err = b.BuildBootstrapKubeconfig("kubelet", c)
 			}
@@ -152,7 +150,7 @@ func (b *KubeletBuilder) Build(c *fi.ModelBuilderContext) error {
 		}
 	}
 
-	if components.UsesCNI(b.Cluster.Spec.Networking) {
+	if components.UsesCNI(&b.Cluster.Spec.Networking) {
 		c.AddTask(&nodetasks.File{
 			Path: b.CNIConfDir(),
 			Type: nodetasks.FileType_Directory,
@@ -285,13 +283,10 @@ func (b *KubeletBuilder) buildSystemdEnvironmentFile(kubeletConfig *kops.Kubelet
 		return nil, fmt.Errorf("error building kubelet flags: %v", err)
 	}
 
-	// Add cloud config file if needed
 	// We build this flag differently because it depends on CloudConfig, and to expose it directly
 	// would be a degree of freedom we don't have (we'd have to write the config to different files)
 	// We can always add this later if it is needed.
-	if b.Cluster.Spec.CloudConfig != nil {
-		flags += " --cloud-config=" + InTreeCloudConfigFilePath
-	}
+	flags += " --cloud-config=" + InTreeCloudConfigFilePath
 
 	if b.UsesSecondaryIP() {
 		localIP, err := b.GetMetadataLocalIP()
@@ -324,7 +319,7 @@ func (b *KubeletBuilder) buildSystemdEnvironmentFile(kubeletConfig *kops.Kubelet
 		if b.Cluster.Spec.Containerd == nil || b.Cluster.Spec.Containerd.Address == nil {
 			flags += " --container-runtime-endpoint=unix:///run/containerd/containerd.sock"
 		} else {
-			flags += " --container-runtime-endpoint=unix://" + fi.StringValue(b.Cluster.Spec.Containerd.Address)
+			flags += " --container-runtime-endpoint=unix://" + fi.ValueOf(b.Cluster.Spec.Containerd.Address)
 		}
 	}
 
@@ -387,8 +382,8 @@ func (b *KubeletBuilder) buildSystemdService() *nodetasks.Service {
 
 	manifest.Set("Install", "WantedBy", "multi-user.target")
 
-	if b.Cluster.Spec.Kubelet.CgroupDriver == "systemd" && b.Cluster.Spec.ContainerRuntime == "containerd" {
-		cgroup := b.Cluster.Spec.Kubelet.KubeletCgroups
+	if b.NodeupConfig.KubeletConfig.CgroupDriver == "systemd" && b.Cluster.Spec.ContainerRuntime == "containerd" {
+		cgroup := b.NodeupConfig.KubeletConfig.KubeletCgroups
 		if cgroup != "" {
 			manifest.Set("Service", "Slice", strings.Trim(cgroup, "/")+".slice")
 		}
@@ -406,7 +401,7 @@ func (b *KubeletBuilder) buildSystemdService() *nodetasks.Service {
 	service.InitDefaults()
 
 	if b.ConfigurationMode == "Warming" {
-		service.Running = fi.Bool(false)
+		service.Running = fi.PtrTo(false)
 	}
 
 	return service
@@ -423,7 +418,7 @@ func (b *KubeletBuilder) usesContainerizedMounter() bool {
 }
 
 // addContainerizedMounter downloads and installs the containerized mounter, that we need on ContainerOS
-func (b *KubeletBuilder) addContainerizedMounter(c *fi.ModelBuilderContext) error {
+func (b *KubeletBuilder) addContainerizedMounter(c *fi.NodeupModelBuilderContext) error {
 	if !b.usesContainerizedMounter() {
 		return nil
 	}
@@ -522,7 +517,6 @@ func (b *KubeletBuilder) addContainerizedMounter(c *fi.ModelBuilderContext) erro
 // buildKubeletConfigSpec returns the kubeletconfig for the specified instanceGroup
 func (b *KubeletBuilder) buildKubeletConfigSpec() (*kops.KubeletConfigSpec, error) {
 	isMaster := b.IsMaster
-	isAPIServer := b.BootConfig.InstanceGroupRole == kops.InstanceGroupRoleAPIServer
 
 	// Merge KubeletConfig for NodeLabels
 	c := b.NodeupConfig.KubeletConfig
@@ -533,7 +527,7 @@ func (b *KubeletBuilder) buildKubeletConfigSpec() (*kops.KubeletConfigSpec, erro
 		c.BootstrapKubeconfig = ""
 	}
 
-	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.AmazonVPC != nil {
+	if b.Cluster.Spec.Networking.AmazonVPC != nil {
 		sess := session.Must(session.NewSession())
 		metadata := ec2metadata.New(sess)
 
@@ -568,29 +562,10 @@ func (b *KubeletBuilder) buildKubeletConfigSpec() (*kops.KubeletConfigSpec, erro
 			}
 
 			// Write back values that could have changed
-			c.MaxPods = fi.Int32(int32(maxPods))
+			c.MaxPods = fi.PtrTo(int32(maxPods))
 		}
 	}
 
-	// Use --register-with-taints
-	{
-		if len(c.Taints) == 0 && isMaster {
-			// (Even though the value is empty, we still expect <Key>=<Value>:<Effect>)
-			if b.IsKubernetesLT("1.24") {
-				c.Taints = append(c.Taints, nodelabels.RoleLabelMaster16+"=:"+string(v1.TaintEffectNoSchedule))
-			} else {
-				c.Taints = append(c.Taints, nodelabels.RoleLabelControlPlane20+"=:"+string(v1.TaintEffectNoSchedule))
-			}
-		}
-		if len(c.Taints) == 0 && isAPIServer {
-			// (Even though the value is empty, we still expect <Key>=<Value>:<Effect>)
-			c.Taints = append(c.Taints, nodelabels.RoleLabelAPIServer16+"=:"+string(v1.TaintEffectNoSchedule))
-		}
-
-		// Enable scheduling since it can be controlled via taints.
-		c.RegisterSchedulable = fi.Bool(true)
-	}
-
 	if c.VolumePluginDirectory == "" {
 		switch b.Distribution {
 		case distributions.DistributionContainerOS:
@@ -624,14 +599,14 @@ func (b *KubeletBuilder) buildKubeletConfigSpec() (*kops.KubeletConfigSpec, erro
 	}
 
 	if c.AuthenticationTokenWebhook == nil {
-		c.AuthenticationTokenWebhook = fi.Bool(true)
+		c.AuthenticationTokenWebhook = fi.PtrTo(true)
 	}
 
 	return &c, nil
 }
 
-// buildMasterKubeletKubeconfig builds a kubeconfig for the master kubelet, self-signing the kubelet cert
-func (b *KubeletBuilder) buildMasterKubeletKubeconfig(c *fi.ModelBuilderContext) (fi.Resource, error) {
+// buildControlPlaneKubeletKubeconfig builds a kubeconfig for the master kubelet, self-signing the kubelet cert
+func (b *KubeletBuilder) buildControlPlaneKubeletKubeconfig(c *fi.NodeupModelBuilderContext) (fi.Resource, error) {
 	nodeName, err := b.NodeName()
 	if err != nil {
 		return nil, fmt.Errorf("error getting NodeName: %v", err)
@@ -644,7 +619,7 @@ func (b *KubeletBuilder) buildMasterKubeletKubeconfig(c *fi.ModelBuilderContext)
 	return b.BuildIssuedKubeconfig("kubelet", certName, c), nil
 }
 
-func (b *KubeletBuilder) buildKubeletServingCertificate(c *fi.ModelBuilderContext) error {
+func (b *KubeletBuilder) buildKubeletServingCertificate(c *fi.NodeupModelBuilderContext) error {
 	if b.UseKopsControllerForNodeBootstrap() {
 		name := "kubelet-server"
 		dir := b.PathSrvKubernetes()
@@ -664,7 +639,7 @@ func (b *KubeletBuilder) buildKubeletServingCertificate(c *fi.ModelBuilderContex
 				Path:           filepath.Join(dir, name+".crt"),
 				Contents:       cert,
 				Type:           nodetasks.FileType_File,
-				Mode:           fi.String("0644"),
+				Mode:           fi.PtrTo("0644"),
 				BeforeServices: []string{"kubelet.service"},
 			})
 
@@ -672,7 +647,7 @@ func (b *KubeletBuilder) buildKubeletServingCertificate(c *fi.ModelBuilderContex
 				Path:           filepath.Join(dir, name+".key"),
 				Contents:       key,
 				Type:           nodetasks.FileType_File,
-				Mode:           fi.String("0400"),
+				Mode:           fi.PtrTo("0400"),
 				BeforeServices: []string{"kubelet.service"},
 			})
 
