@@ -17,6 +17,8 @@ limitations under the License.
 package kops
 
 import (
+	"strings"
+
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -31,7 +33,7 @@ const (
 // +genclient
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
 
-// InstanceGroup represents a group of instances (either nodes or masters) with the same configuration
+// InstanceGroup represents a group of instances with the same configuration.
 type InstanceGroup struct {
 	metav1.TypeMeta   `json:",inline"`
 	metav1.ObjectMeta `json:"metadata,omitempty"`
@@ -49,23 +51,23 @@ type InstanceGroupList struct {
 	Items []InstanceGroup `json:"items"`
 }
 
-// InstanceGroupRole describes the roles of the nodes in this InstanceGroup (master or nodes)
+// InstanceGroupRole describes the roles of the nodes in this InstanceGroup.
 type InstanceGroupRole string
 
 const (
-	// InstanceGroupRoleMaster is a master role
-	InstanceGroupRoleMaster InstanceGroupRole = "Master"
-	// InstanceGroupRoleNode is a node role
+	// InstanceGroupRoleControlPlane is a control-plane role.
+	InstanceGroupRoleControlPlane InstanceGroupRole = "ControlPlane"
+	// InstanceGroupRoleNode is a node role.
 	InstanceGroupRoleNode InstanceGroupRole = "Node"
-	// InstanceGroupRoleBastion is a bastion role
+	// InstanceGroupRoleBastion is a bastion role.
 	InstanceGroupRoleBastion InstanceGroupRole = "Bastion"
-	// InstanceGroupRoleAPIServer is an API server role
+	// InstanceGroupRoleAPIServer is an API server role.
 	InstanceGroupRoleAPIServer InstanceGroupRole = "APIServer"
 )
 
 // AllInstanceGroupRoles is a slice of all valid InstanceGroupRole values
 var AllInstanceGroupRoles = []InstanceGroupRole{
-	InstanceGroupRoleMaster,
+	InstanceGroupRoleControlPlane,
 	InstanceGroupRoleAPIServer,
 	InstanceGroupRoleNode,
 	InstanceGroupRoleBastion,
@@ -94,7 +96,7 @@ const (
 type InstanceGroupSpec struct {
 	// Manager determines what is managing the node lifecycle
 	Manager InstanceManager `json:"manager,omitempty"`
-	// Type determines the role of instances in this instance group: masters or nodes
+	// Role determines the role of instances in this instance group.
 	Role InstanceGroupRole `json:"role,omitempty"`
 	// Image is the instance (ami etc) we should use
 	Image string `json:"image,omitempty"`
@@ -104,6 +106,8 @@ type InstanceGroupSpec struct {
 	MaxSize *int32 `json:"maxSize,omitempty"`
 	// Autoscale determines if autoscaling will be enabled for this instance group if cluster autoscaler is enabled
 	Autoscale *bool `json:"autoscale,omitempty"`
+	// AutoscalePriority determines the InstanceGroup priority for scaling when cluster autoscaler uses the priority expander.
+	AutoscalePriority int16 `json:"autoscalePriority,omitempty"`
 	// MachineType is the instance class
 	MachineType string `json:"machineType,omitempty"`
 	// RootVolumeSize is the size of the EBS root volume to use, in GB
@@ -155,12 +159,14 @@ type InstanceGroupSpec struct {
 	Taints []string `json:"taints,omitempty"`
 	// MixedInstancesPolicy defined a optional backing of an AWS ASG by a EC2 Fleet (AWS Only)
 	MixedInstancesPolicy *MixedInstancesPolicySpec `json:"mixedInstancesPolicy,omitempty"`
+	// CapacityRebalance makes ASGs proactively replace spot instances when the ASG receives a rebalance recommendation (AWS Only).
+	CapacityRebalance *bool `json:"capacityRebalance,omitempty"`
 	// AdditionalUserData is any additional user-data to be passed to the host
 	AdditionalUserData []UserData `json:"additionalUserData,omitempty"`
 	// SuspendProcesses disables the listed Scaling Policies
 	SuspendProcesses []string `json:"suspendProcesses,omitempty"`
 	// ExternalLoadBalancers define loadbalancers that should be attached to this instance group
-	ExternalLoadBalancers []LoadBalancer `json:"externalLoadBalancers,omitempty"`
+	ExternalLoadBalancers []LoadBalancerSpec `json:"externalLoadBalancers,omitempty"`
 	// DetailedInstanceMonitoring defines if detailed-monitoring is enabled (AWS only)
 	DetailedInstanceMonitoring *bool `json:"detailedInstanceMonitoring,omitempty"`
 	// IAMProfileSpec defines the identity of the cloud group IAM profile (AWS only).
@@ -327,10 +333,10 @@ type IAMProfileSpec struct {
 	Profile *string `json:"profile,omitempty"`
 }
 
-// IsMaster checks if instanceGroup is a master
-func (g *InstanceGroup) IsMaster() bool {
+// IsControlPlane checks if instanceGroup is a control-plane node.
+func (g *InstanceGroup) IsControlPlane() bool {
 	switch g.Spec.Role {
-	case InstanceGroupRoleMaster:
+	case InstanceGroupRoleControlPlane:
 		return true
 	default:
 		return false
@@ -349,7 +355,7 @@ func (g *InstanceGroup) IsAPIServerOnly() bool {
 
 // hasAPIServer checks if instanceGroup runs an API Server
 func (g *InstanceGroup) HasAPIServer() bool {
-	return g.IsMaster() || g.IsAPIServerOnly()
+	return g.IsControlPlane() || g.IsAPIServerOnly()
 }
 
 // IsBastion checks if instanceGroup is a bastion
@@ -369,8 +375,17 @@ func (g *InstanceGroup) AddInstanceGroupNodeLabel() {
 	g.Spec.NodeLabels[NodeLabelInstanceGroup] = g.Name
 }
 
+func (r InstanceGroupRole) ToLowerString() string {
+	switch r {
+	case InstanceGroupRoleControlPlane:
+		return "control-plane"
+	default:
+		return strings.ToLower(string(r))
+	}
+}
+
 // LoadBalancer defines a load balancer
-type LoadBalancer struct {
+type LoadBalancerSpec struct {
 	// LoadBalancerName to associate with this instance group (AWS ELB)
 	LoadBalancerName *string `json:"loadBalancerName,omitempty"`
 	// TargetGroupARN to associate with this instance group (AWS ALB/NLB)
