@@ -40,9 +40,11 @@ func TestAWSValidateExternalCloudConfig(t *testing.T) {
 		{
 			Input: kops.ClusterSpec{
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{},
-				CloudConfig: &kops.CloudConfiguration{
-					AWSEBSCSIDriver: &kops.AWSEBSCSIDriver{
-						Enabled: fi.Bool(false),
+				CloudProvider: kops.CloudProviderSpec{
+					AWS: &kops.AWSSpec{
+						EBSCSIDriver: &kops.EBSCSIDriverSpec{
+							Enabled: fi.PtrTo(false),
+						},
 					},
 				},
 			},
@@ -51,9 +53,11 @@ func TestAWSValidateExternalCloudConfig(t *testing.T) {
 		{
 			Input: kops.ClusterSpec{
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{},
-				CloudConfig: &kops.CloudConfiguration{
-					AWSEBSCSIDriver: &kops.AWSEBSCSIDriver{
-						Enabled: fi.Bool(true),
+				CloudProvider: kops.CloudProviderSpec{
+					AWS: &kops.AWSSpec{
+						EBSCSIDriver: &kops.EBSCSIDriverSpec{
+							Enabled: fi.PtrTo(true),
+						},
 					},
 				},
 			},
@@ -61,6 +65,9 @@ func TestAWSValidateExternalCloudConfig(t *testing.T) {
 		{
 			Input: kops.ClusterSpec{
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{},
+				CloudProvider: kops.CloudProviderSpec{
+					AWS: &kops.AWSSpec{},
+				},
 				KubeControllerManager: &kops.KubeControllerManagerConfig{
 					ExternalCloudVolumePlugin: "aws",
 				},
@@ -152,7 +159,7 @@ func TestValidateInstanceGroupSpec(t *testing.T) {
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				SpotDurationInMinutes: fi.Int64(55),
+				SpotDurationInMinutes: fi.PtrTo(int64(55)),
 			},
 			ExpectedErrors: []string{
 				"Unsupported value::test-nodes.spec.spotDurationInMinutes",
@@ -160,7 +167,7 @@ func TestValidateInstanceGroupSpec(t *testing.T) {
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				SpotDurationInMinutes: fi.Int64(380),
+				SpotDurationInMinutes: fi.PtrTo(int64(380)),
 			},
 			ExpectedErrors: []string{
 				"Unsupported value::test-nodes.spec.spotDurationInMinutes",
@@ -168,7 +175,7 @@ func TestValidateInstanceGroupSpec(t *testing.T) {
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				SpotDurationInMinutes: fi.Int64(125),
+				SpotDurationInMinutes: fi.PtrTo(int64(125)),
 			},
 			ExpectedErrors: []string{
 				"Unsupported value::test-nodes.spec.spotDurationInMinutes",
@@ -176,13 +183,13 @@ func TestValidateInstanceGroupSpec(t *testing.T) {
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				SpotDurationInMinutes: fi.Int64(120),
+				SpotDurationInMinutes: fi.PtrTo(int64(120)),
 			},
 			ExpectedErrors: []string{},
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				InstanceInterruptionBehavior: fi.String("invalidValue"),
+				InstanceInterruptionBehavior: fi.PtrTo("invalidValue"),
 			},
 			ExpectedErrors: []string{
 				"Unsupported value::test-nodes.spec.instanceInterruptionBehavior",
@@ -190,19 +197,19 @@ func TestValidateInstanceGroupSpec(t *testing.T) {
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				InstanceInterruptionBehavior: fi.String("terminate"),
+				InstanceInterruptionBehavior: fi.PtrTo("terminate"),
 			},
 			ExpectedErrors: []string{},
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				InstanceInterruptionBehavior: fi.String("hibernate"),
+				InstanceInterruptionBehavior: fi.PtrTo("hibernate"),
 			},
 			ExpectedErrors: []string{},
 		},
 		{
 			Input: kops.InstanceGroupSpec{
-				InstanceInterruptionBehavior: fi.String("stop"),
+				InstanceInterruptionBehavior: fi.PtrTo("stop"),
 			},
 			ExpectedErrors: []string{},
 		},
@@ -322,7 +329,7 @@ func TestMixedInstancePolicies(t *testing.T) {
 						"c4.large",
 						"c5.large",
 					},
-					OnDemandAboveBase: fi.Int64(231),
+					OnDemandAboveBase: fi.PtrTo(int64(231)),
 				},
 			},
 			ExpectedErrors: []string{"Invalid value::spec.mixedInstancesPolicy.onDemandAboveBase"},
@@ -381,8 +388,8 @@ func TestInstanceMetadataOptions(t *testing.T) {
 				Spec: kops.InstanceGroupSpec{
 					Role: "Node",
 					InstanceMetadata: &kops.InstanceMetadataOptions{
-						HTTPPutResponseHopLimit: fi.Int64(1),
-						HTTPTokens:              fi.String("abc"),
+						HTTPPutResponseHopLimit: fi.PtrTo(int64(1)),
+						HTTPTokens:              fi.PtrTo("abc"),
 					},
 					MachineType: "t3.medium",
 				},
@@ -397,8 +404,8 @@ func TestInstanceMetadataOptions(t *testing.T) {
 				Spec: kops.InstanceGroupSpec{
 					Role: "Node",
 					InstanceMetadata: &kops.InstanceMetadataOptions{
-						HTTPPutResponseHopLimit: fi.Int64(-1),
-						HTTPTokens:              fi.String("required"),
+						HTTPPutResponseHopLimit: fi.PtrTo(int64(-1)),
+						HTTPTokens:              fi.PtrTo("required"),
 					},
 					MachineType: "t3.medium",
 				},
@@ -442,7 +449,7 @@ func TestLoadBalancerSubnets(t *testing.T) {
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
-					PrivateIPv4Address: fi.String("10.0.0.10"),
+					PrivateIPv4Address: fi.PtrTo("10.0.0.10"),
 					AllocationID:       nil,
 				},
 				{
@@ -479,7 +486,7 @@ func TestLoadBalancerSubnets(t *testing.T) {
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
-					PrivateIPv4Address: fi.String(""),
+					PrivateIPv4Address: fi.PtrTo(""),
 					AllocationID:       nil,
 				},
 			},
@@ -491,7 +498,7 @@ func TestLoadBalancerSubnets(t *testing.T) {
 				{
 					Name:               "a",
 					PrivateIPv4Address: nil,
-					AllocationID:       fi.String(""),
+					AllocationID:       fi.PtrTo(""),
 				},
 			},
 			expected: []string{"Required value::spec.api.loadBalancer.subnets[0].allocationID"},
@@ -501,7 +508,7 @@ func TestLoadBalancerSubnets(t *testing.T) {
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
-					PrivateIPv4Address: fi.String("invalidip"),
+					PrivateIPv4Address: fi.PtrTo("invalidip"),
 					AllocationID:       nil,
 				},
 			},
@@ -512,56 +519,56 @@ func TestLoadBalancerSubnets(t *testing.T) {
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
-					PrivateIPv4Address: fi.String("11.0.0.10"),
+					PrivateIPv4Address: fi.PtrTo("11.0.0.10"),
 					AllocationID:       nil,
 				},
 			},
 			expected: []string{"Invalid value::spec.api.loadBalancer.subnets[0].privateIPv4Address"},
 		},
 		{ // invalid class - with privateIPv4Address, no allocationID
-			class:          fi.String(string(kops.LoadBalancerClassClassic)),
+			class:          fi.PtrTo(string(kops.LoadBalancerClassClassic)),
 			clusterSubnets: []string{"a", "b", "c"},
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
-					PrivateIPv4Address: fi.String("10.0.0.10"),
+					PrivateIPv4Address: fi.PtrTo("10.0.0.10"),
 					AllocationID:       nil,
 				},
 			},
 			expected: []string{"Forbidden::spec.api.loadBalancer.subnets[0].privateIPv4Address"},
 		},
 		{ // invalid class - no privateIPv4Address, with allocationID
-			class:          fi.String(string(kops.LoadBalancerClassClassic)),
+			class:          fi.PtrTo(string(kops.LoadBalancerClassClassic)),
 			clusterSubnets: []string{"a", "b", "c"},
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
 					PrivateIPv4Address: nil,
-					AllocationID:       fi.String("eipalloc-222ghi789"),
+					AllocationID:       fi.PtrTo("eipalloc-222ghi789"),
 				},
 			},
 			expected: []string{"Forbidden::spec.api.loadBalancer.subnets[0].allocationID"},
 		},
 		{ // invalid type external for private IP
-			lbType:         fi.String(string(kops.LoadBalancerTypePublic)),
+			lbType:         fi.PtrTo(string(kops.LoadBalancerTypePublic)),
 			clusterSubnets: []string{"a", "b", "c"},
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
-					PrivateIPv4Address: fi.String("10.0.0.10"),
+					PrivateIPv4Address: fi.PtrTo("10.0.0.10"),
 					AllocationID:       nil,
 				},
 			},
 			expected: []string{"Forbidden::spec.api.loadBalancer.subnets[0].privateIPv4Address"},
 		},
 		{ // invalid type Internal for public IP
-			lbType:         fi.String(string(kops.LoadBalancerTypeInternal)),
+			lbType:         fi.PtrTo(string(kops.LoadBalancerTypeInternal)),
 			clusterSubnets: []string{"a", "b", "c"},
 			lbSubnets: []kops.LoadBalancerSubnetSpec{
 				{
 					Name:               "a",
 					PrivateIPv4Address: nil,
-					AllocationID:       fi.String("eipalloc-222ghi789"),
+					AllocationID:       fi.PtrTo("eipalloc-222ghi789"),
 				},
 			},
 			expected: []string{"Forbidden::spec.api.loadBalancer.subnets[0].allocationID"},
@@ -571,7 +578,7 @@ func TestLoadBalancerSubnets(t *testing.T) {
 	for _, test := range tests {
 		cluster := kops.Cluster{
 			Spec: kops.ClusterSpec{
-				API: &kops.AccessSpec{
+				API: kops.APISpec{
 					LoadBalancer: &kops.LoadBalancerAccessSpec{
 						Class: kops.LoadBalancerClassNetwork,
 						Type:  kops.LoadBalancerTypeInternal,
@@ -586,7 +593,7 @@ func TestLoadBalancerSubnets(t *testing.T) {
 			cluster.Spec.API.LoadBalancer.Type = kops.LoadBalancerType(*test.lbType)
 		}
 		for _, s := range test.clusterSubnets {
-			cluster.Spec.Subnets = append(cluster.Spec.Subnets, kops.ClusterSubnetSpec{
+			cluster.Spec.Networking.Subnets = append(cluster.Spec.Networking.Subnets, kops.ClusterSubnetSpec{
 				Name: s,
 				CIDR: cidr,
 			})
@@ -744,7 +751,7 @@ func TestAWSAdditionalRoutes(t *testing.T) {
 					Target: "pcx-abcdef",
 				},
 			},
-			expected: []string{"Invalid value::spec.networkCIDR"},
+			expected: []string{"Invalid value::spec.networking.networkCIDR"},
 		},
 		{ // bad cidr
 			clusterCidr: "100.64.0.0/10",
@@ -755,7 +762,7 @@ func TestAWSAdditionalRoutes(t *testing.T) {
 					Target: "pcx-abcdef",
 				},
 			},
-			expected: []string{"Invalid value::spec.subnets[0].additionalRoutes[0].cidr"},
+			expected: []string{"Invalid value::spec.networking.subnets[0].additionalRoutes[0].cidr"},
 		},
 		{ // bad target
 			clusterCidr: "100.64.0.0/10",
@@ -766,7 +773,7 @@ func TestAWSAdditionalRoutes(t *testing.T) {
 					Target: "unknown-abcdef",
 				},
 			},
-			expected: []string{"Invalid value::spec.subnets[0].additionalRoutes[0].target"},
+			expected: []string{"Invalid value::spec.networking.subnets[0].additionalRoutes[0].target"},
 		},
 		{ // target more specific
 			clusterCidr: "100.64.0.0/10",
@@ -777,7 +784,7 @@ func TestAWSAdditionalRoutes(t *testing.T) {
 					Target: "pcx-abcdef",
 				},
 			},
-			expected: []string{"Forbidden::spec.subnets[0].additionalRoutes[0].target"},
+			expected: []string{"Forbidden::spec.networking.subnets[0].additionalRoutes[0].target"},
 		},
 		{ // duplicates cidr
 			clusterCidr: "100.64.0.0/10",
@@ -792,7 +799,7 @@ func TestAWSAdditionalRoutes(t *testing.T) {
 					Target: "tgw-abcdef",
 				},
 			},
-			expected: []string{"Duplicate value::spec.subnets[0].additionalRoutes[1].cidr"},
+			expected: []string{"Duplicate value::spec.networking.subnets[0].additionalRoutes[1].cidr"},
 		},
 		{ // shared subnet
 			clusterCidr: "100.64.0.0/10",
@@ -804,7 +811,7 @@ func TestAWSAdditionalRoutes(t *testing.T) {
 					Target: "pcx-abcdef",
 				},
 			},
-			expected: []string{"Invalid value::spec.subnets[0]"},
+			expected: []string{"Invalid value::spec.networking.subnets[0]"},
 		},
 		{ // not a private subnet
 			clusterCidr: "100.64.0.0/10",
@@ -815,19 +822,21 @@ func TestAWSAdditionalRoutes(t *testing.T) {
 					Target: "pcx-abcdef",
 				},
 			},
-			expected: []string{"Invalid value::spec.subnets[0]"},
+			expected: []string{"Invalid value::spec.networking.subnets[0]"},
 		},
 	}
 
 	for _, test := range tests {
 		cluster := kops.Cluster{
 			Spec: kops.ClusterSpec{
-				NetworkCIDR: test.clusterCidr,
-				Subnets: []kops.ClusterSubnetSpec{
-					{
-						ProviderID:       test.providerId,
-						Type:             test.subnetType,
-						AdditionalRoutes: test.route,
+				Networking: kops.NetworkingSpec{
+					NetworkCIDR: test.clusterCidr,
+					Subnets: []kops.ClusterSubnetSpec{
+						{
+							ID:               test.providerId,
+							Type:             test.subnetType,
+							AdditionalRoutes: test.route,
+						},
 					},
 				},
 			},
