@@ -60,10 +60,10 @@ type AutoscalingGroupModelBuilder struct {
 	Cluster                *kops.Cluster
 }
 
-var _ fi.ModelBuilder = &AutoscalingGroupModelBuilder{}
+var _ fi.CloudupModelBuilder = &AutoscalingGroupModelBuilder{}
 
 // Build is responsible for constructing the aws autoscaling group from the kops spec
-func (b *AutoscalingGroupModelBuilder) Build(c *fi.ModelBuilderContext) error {
+func (b *AutoscalingGroupModelBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 	for _, ig := range b.InstanceGroups {
 		name := b.AutoscalingGroupName(ig)
 
@@ -89,9 +89,9 @@ func (b *AutoscalingGroupModelBuilder) Build(c *fi.ModelBuilderContext) error {
 			tsk.LaunchTemplate = task
 			c.AddTask(tsk)
 
-			warmPool := b.Cluster.Spec.WarmPool.ResolveDefaults(ig)
+			warmPool := b.Cluster.Spec.CloudProvider.AWS.WarmPool.ResolveDefaults(ig)
 
-			enabled := fi.Bool(warmPool.IsEnabled())
+			enabled := fi.PtrTo(warmPool.IsEnabled())
 			warmPoolTask := &awstasks.WarmPool{
 				Name:      &name,
 				Lifecycle: b.Lifecycle,
@@ -100,7 +100,9 @@ func (b *AutoscalingGroupModelBuilder) Build(c *fi.ModelBuilderContext) error {
 			if warmPool.IsEnabled() {
 				warmPoolTask.MinSize = warmPool.MinSize
 				warmPoolTask.MaxSize = warmPool.MaxSize
-
+				tsk.WarmPool = warmPoolTask
+			} else {
+				tsk.WarmPool = nil
 			}
 			c.AddTask(warmPoolTask)
 
@@ -131,7 +133,7 @@ func (b *AutoscalingGroupModelBuilder) Build(c *fi.ModelBuilderContext) error {
 }
 
 // buildLaunchTemplateTask is responsible for creating the template task into the aws model
-func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.ModelBuilderContext, name string, ig *kops.InstanceGroup) (*awstasks.LaunchTemplate, error) {
+func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.CloudupModelBuilderContext, name string, ig *kops.InstanceGroup) (*awstasks.LaunchTemplate, error) {
 	// @step: add the iam instance profile
 	link, err := b.LinkToIAMInstanceProfile(ig)
 	if err != nil {
@@ -142,22 +144,22 @@ func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.ModelBuilde
 	if err != nil {
 		return nil, err
 	}
-	if fi.Int32Value(ig.Spec.RootVolumeSize) > 0 {
-		rootVolumeSize = fi.Int32Value(ig.Spec.RootVolumeSize)
+	if fi.ValueOf(ig.Spec.RootVolumeSize) > 0 {
+		rootVolumeSize = fi.ValueOf(ig.Spec.RootVolumeSize)
 	}
 
-	rootVolumeType := fi.StringValue(ig.Spec.RootVolumeType)
+	rootVolumeType := fi.ValueOf(ig.Spec.RootVolumeType)
 	if rootVolumeType == "" {
 		rootVolumeType = DefaultVolumeType
 	}
 
 	rootVolumeEncryption := DefaultVolumeEncryption
 	if ig.Spec.RootVolumeEncryption != nil {
-		rootVolumeEncryption = fi.BoolValue(ig.Spec.RootVolumeEncryption)
+		rootVolumeEncryption = fi.ValueOf(ig.Spec.RootVolumeEncryption)
 	}
 
 	rootVolumeKmsKey := ""
-	if fi.BoolValue(ig.Spec.RootVolumeEncryption) && ig.Spec.RootVolumeEncryptionKey != nil {
+	if fi.ValueOf(ig.Spec.RootVolumeEncryption) && ig.Spec.RootVolumeEncryptionKey != nil {
 		rootVolumeKmsKey = *ig.Spec.RootVolumeEncryptionKey
 	}
 
@@ -177,30 +179,30 @@ func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.ModelBuilde
 	}
 
 	lt := &awstasks.LaunchTemplate{
-		Name:                         fi.String(name),
+		Name:                         fi.PtrTo(name),
 		Lifecycle:                    b.Lifecycle,
-		CPUCredits:                   fi.String(fi.StringValue(ig.Spec.CPUCredits)),
-		HTTPPutResponseHopLimit:      fi.Int64(1),
-		HTTPTokens:                   fi.String(ec2.LaunchTemplateHttpTokensStateOptional),
-		HTTPProtocolIPv6:             fi.String(ec2.LaunchTemplateInstanceMetadataProtocolIpv6Disabled),
+		CPUCredits:                   fi.PtrTo(fi.ValueOf(ig.Spec.CPUCredits)),
+		HTTPPutResponseHopLimit:      fi.PtrTo(int64(1)),
+		HTTPTokens:                   fi.PtrTo(ec2.LaunchTemplateHttpTokensStateOptional),
+		HTTPProtocolIPv6:             fi.PtrTo(ec2.LaunchTemplateInstanceMetadataProtocolIpv6Disabled),
 		IAMInstanceProfile:           link,
-		ImageID:                      fi.String(ig.Spec.Image),
+		ImageID:                      fi.PtrTo(ig.Spec.Image),
 		InstanceInterruptionBehavior: ig.Spec.InstanceInterruptionBehavior,
-		InstanceMonitoring:           fi.Bool(false),
-		IPv6AddressCount:             fi.Int64(0),
-		RootVolumeIops:               fi.Int64(int64(fi.Int32Value(ig.Spec.RootVolumeIOPS))),
+		InstanceMonitoring:           fi.PtrTo(false),
+		IPv6AddressCount:             fi.PtrTo(int64(0)),
+		RootVolumeIops:               fi.PtrTo(int64(fi.ValueOf(ig.Spec.RootVolumeIOPS))),
 		RootVolumeOptimization:       ig.Spec.RootVolumeOptimization,
-		RootVolumeSize:               fi.Int64(int64(rootVolumeSize)),
-		RootVolumeType:               fi.String(rootVolumeType),
-		RootVolumeEncryption:         fi.Bool(rootVolumeEncryption),
-		RootVolumeKmsKey:             fi.String(rootVolumeKmsKey),
+		RootVolumeSize:               fi.PtrTo(int64(rootVolumeSize)),
+		RootVolumeType:               fi.PtrTo(rootVolumeType),
+		RootVolumeEncryption:         fi.PtrTo(rootVolumeEncryption),
+		RootVolumeKmsKey:             fi.PtrTo(rootVolumeKmsKey),
 		SecurityGroups:               securityGroups,
 		Tags:                         tags,
 		UserData:                     userData,
 	}
 
 	if ig.Spec.Manager == kops.InstanceManagerCloudGroup {
-		lt.InstanceType = fi.String(strings.Split(ig.Spec.MachineType, ",")[0])
+		lt.InstanceType = fi.PtrTo(strings.Split(ig.Spec.MachineType, ",")[0])
 	}
 
 	{
@@ -213,23 +215,23 @@ func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.ModelBuilde
 		// @step: check if we can add a public ip to this subnet
 		switch subnets[0].Type {
 		case kops.SubnetTypePublic, kops.SubnetTypeUtility:
-			lt.AssociatePublicIP = fi.Bool(true)
+			lt.AssociatePublicIP = fi.PtrTo(true)
 			if ig.Spec.AssociatePublicIP != nil {
 				lt.AssociatePublicIP = ig.Spec.AssociatePublicIP
 			}
 		case kops.SubnetTypeDualStack, kops.SubnetTypePrivate:
-			lt.AssociatePublicIP = fi.Bool(false)
+			lt.AssociatePublicIP = fi.PtrTo(false)
 		}
 
 		// @step: add an IPv6 address
-		for _, clusterSubnet := range b.Cluster.Spec.Subnets {
+		for _, clusterSubnet := range b.Cluster.Spec.Networking.Subnets {
 			for _, igSubnet := range ig.Spec.Subnets {
 				if clusterSubnet.Name != igSubnet {
 					continue
 				}
 				if clusterSubnet.IPv6CIDR != "" {
-					lt.IPv6AddressCount = fi.Int64(1)
-					lt.HTTPProtocolIPv6 = fi.String(ec2.LaunchTemplateInstanceMetadataProtocolIpv6Enabled)
+					lt.IPv6AddressCount = fi.PtrTo(int64(1))
+					lt.HTTPProtocolIPv6 = fi.PtrTo(ec2.LaunchTemplateInstanceMetadataProtocolIpv6Enabled)
 				}
 			}
 		}
@@ -243,35 +245,35 @@ func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.ModelBuilde
 		}
 		if x.Type == ec2.VolumeTypeIo1 || x.Type == ec2.VolumeTypeIo2 {
 			if x.IOPS == nil {
-				x.IOPS = fi.Int64(DefaultVolumeIonIops)
+				x.IOPS = fi.PtrTo(int64(DefaultVolumeIonIops))
 			}
 		} else if x.Type == ec2.VolumeTypeGp3 {
 			if x.IOPS == nil {
-				x.IOPS = fi.Int64(DefaultVolumeGp3Iops)
+				x.IOPS = fi.PtrTo(int64(DefaultVolumeGp3Iops))
 			}
 			if x.Throughput == nil {
-				x.Throughput = fi.Int64(DefaultVolumeGp3Throughput)
+				x.Throughput = fi.PtrTo(int64(DefaultVolumeGp3Throughput))
 			}
 		} else {
 			x.IOPS = nil
 		}
 		deleteOnTermination := DefaultVolumeDeleteOnTermination
 		if x.DeleteOnTermination != nil {
-			deleteOnTermination = fi.BoolValue(x.DeleteOnTermination)
+			deleteOnTermination = fi.ValueOf(x.DeleteOnTermination)
 		}
 		encryption := DefaultVolumeEncryption
 		if x.Encrypted != nil {
-			encryption = fi.BoolValue(x.Encrypted)
+			encryption = fi.ValueOf(x.Encrypted)
 		}
 		lt.BlockDeviceMappings = append(lt.BlockDeviceMappings, &awstasks.BlockDeviceMapping{
-			DeviceName:             fi.String(x.Device),
-			EbsDeleteOnTermination: fi.Bool(deleteOnTermination),
-			EbsEncrypted:           fi.Bool(encryption),
+			DeviceName:             fi.PtrTo(x.Device),
+			EbsDeleteOnTermination: fi.PtrTo(deleteOnTermination),
+			EbsEncrypted:           fi.PtrTo(encryption),
 			EbsKmsKey:              x.Key,
 			EbsVolumeIops:          x.IOPS,
-			EbsVolumeSize:          fi.Int64(x.Size),
+			EbsVolumeSize:          fi.PtrTo(x.Size),
 			EbsVolumeThroughput:    x.Throughput,
-			EbsVolumeType:          fi.String(x.Type),
+			EbsVolumeType:          fi.PtrTo(x.Type),
 		})
 	}
 
@@ -288,17 +290,17 @@ func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.ModelBuilde
 	}
 
 	if rootVolumeType == ec2.VolumeTypeIo1 || rootVolumeType == ec2.VolumeTypeIo2 {
-		if fi.Int32Value(ig.Spec.RootVolumeIOPS) < 100 {
-			lt.RootVolumeIops = fi.Int64(int64(DefaultVolumeIonIops))
+		if fi.ValueOf(ig.Spec.RootVolumeIOPS) < 100 {
+			lt.RootVolumeIops = fi.PtrTo(int64(DefaultVolumeIonIops))
 		}
 	} else if rootVolumeType == ec2.VolumeTypeGp3 {
-		if fi.Int32Value(ig.Spec.RootVolumeIOPS) < 3000 {
-			lt.RootVolumeIops = fi.Int64(int64(DefaultVolumeGp3Iops))
+		if fi.ValueOf(ig.Spec.RootVolumeIOPS) < 3000 {
+			lt.RootVolumeIops = fi.PtrTo(int64(DefaultVolumeGp3Iops))
 		}
-		if fi.Int32Value(ig.Spec.RootVolumeThroughput) < 125 {
-			lt.RootVolumeThroughput = fi.Int64(int64(DefaultVolumeGp3Throughput))
+		if fi.ValueOf(ig.Spec.RootVolumeThroughput) < 125 {
+			lt.RootVolumeThroughput = fi.PtrTo(int64(DefaultVolumeGp3Throughput))
 		} else {
-			lt.RootVolumeThroughput = fi.Int64(int64(fi.Int32Value(ig.Spec.RootVolumeThroughput)))
+			lt.RootVolumeThroughput = fi.PtrTo(int64(fi.ValueOf(ig.Spec.RootVolumeThroughput)))
 		}
 	} else {
 		lt.RootVolumeIops = nil
@@ -317,29 +319,29 @@ func (b *AutoscalingGroupModelBuilder) buildLaunchTemplateTask(c *fi.ModelBuilde
 	if ig.Spec.MixedInstancesPolicy == nil && ig.Spec.MaxPrice != nil {
 		lt.SpotPrice = ig.Spec.MaxPrice
 	} else {
-		lt.SpotPrice = fi.String("")
+		lt.SpotPrice = fi.PtrTo("")
 	}
 	if ig.Spec.SpotDurationInMinutes != nil {
 		lt.SpotDurationInMinutes = ig.Spec.SpotDurationInMinutes
 	}
 
 	if ig.Spec.Tenancy != "" {
-		lt.Tenancy = fi.String(ig.Spec.Tenancy)
+		lt.Tenancy = fi.PtrTo(ig.Spec.Tenancy)
 	}
 
 	return lt, nil
 }
 
 // buildSecurityGroups is responsible for building security groups for a launch template.
-func (b *AutoscalingGroupModelBuilder) buildSecurityGroups(c *fi.ModelBuilderContext, ig *kops.InstanceGroup) ([]*awstasks.SecurityGroup, error) {
+func (b *AutoscalingGroupModelBuilder) buildSecurityGroups(c *fi.CloudupModelBuilderContext, ig *kops.InstanceGroup) ([]*awstasks.SecurityGroup, error) {
 	// @step: if required we add the override for the security group for this instancegroup
 	sgLink := b.LinkToSecurityGroup(ig.Spec.Role)
 	if ig.Spec.SecurityGroupOverride != nil {
-		sgName := fmt.Sprintf("%v-%v", fi.StringValue(ig.Spec.SecurityGroupOverride), ig.Spec.Role)
+		sgName := fmt.Sprintf("%v-%v", fi.ValueOf(ig.Spec.SecurityGroupOverride), ig.Spec.Role)
 		sgLink = &awstasks.SecurityGroup{
 			ID:     ig.Spec.SecurityGroupOverride,
 			Name:   &sgName,
-			Shared: fi.Bool(true),
+			Shared: fi.PtrTo(true),
 		}
 	}
 
@@ -349,10 +351,10 @@ func (b *AutoscalingGroupModelBuilder) buildSecurityGroups(c *fi.ModelBuilderCon
 		b.APILoadBalancerClass() == kops.LoadBalancerClassNetwork {
 		for _, id := range b.Cluster.Spec.API.LoadBalancer.AdditionalSecurityGroups {
 			sgTask := &awstasks.SecurityGroup{
-				ID:        fi.String(id),
+				ID:        fi.PtrTo(id),
 				Lifecycle: b.SecurityLifecycle,
-				Name:      fi.String("nlb-" + id),
-				Shared:    fi.Bool(true),
+				Name:      fi.PtrTo("nlb-" + id),
+				Shared:    fi.PtrTo(true),
 			}
 			if err := c.EnsureTask(sgTask); err != nil {
 				return nil, err
@@ -364,10 +366,10 @@ func (b *AutoscalingGroupModelBuilder) buildSecurityGroups(c *fi.ModelBuilderCon
 	// @step: add any additional security groups to the instancegroup
 	for _, id := range ig.Spec.AdditionalSecurityGroups {
 		sgTask := &awstasks.SecurityGroup{
-			ID:        fi.String(id),
+			ID:        fi.PtrTo(id),
 			Lifecycle: b.SecurityLifecycle,
-			Name:      fi.String(id),
-			Shared:    fi.Bool(true),
+			Name:      fi.PtrTo(id),
+			Shared:    fi.PtrTo(true),
 		}
 		if err := c.EnsureTask(sgTask); err != nil {
 			return nil, err
@@ -379,12 +381,12 @@ func (b *AutoscalingGroupModelBuilder) buildSecurityGroups(c *fi.ModelBuilderCon
 }
 
 // buildAutoscalingGroupTask is responsible for building the autoscaling task into the model
-func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuilderContext, name string, ig *kops.InstanceGroup) (*awstasks.AutoscalingGroup, error) {
+func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.CloudupModelBuilderContext, name string, ig *kops.InstanceGroup) (*awstasks.AutoscalingGroup, error) {
 	t := &awstasks.AutoscalingGroup{
-		Name:      fi.String(name),
+		Name:      fi.PtrTo(name),
 		Lifecycle: b.Lifecycle,
 
-		Granularity: fi.String("1Minute"),
+		Granularity: fi.PtrTo("1Minute"),
 		Metrics: []string{
 			"GroupDesiredCapacity",
 			"GroupInServiceInstances",
@@ -396,20 +398,20 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 			"GroupTotalInstances",
 		},
 
-		InstanceProtection: fi.Bool(false),
+		InstanceProtection: fi.PtrTo(false),
 	}
 
-	minSize := fi.Int64(1)
-	maxSize := fi.Int64(1)
+	minSize := fi.PtrTo(int64(1))
+	maxSize := fi.PtrTo(int64(1))
 	if ig.Spec.MinSize != nil {
-		minSize = fi.Int64(int64(*ig.Spec.MinSize))
+		minSize = fi.PtrTo(int64(*ig.Spec.MinSize))
 	} else if ig.Spec.Role == kops.InstanceGroupRoleNode {
-		minSize = fi.Int64(2)
+		minSize = fi.PtrTo(int64(2))
 	}
 	if ig.Spec.MaxSize != nil {
-		maxSize = fi.Int64(int64(*ig.Spec.MaxSize))
+		maxSize = fi.PtrTo(int64(*ig.Spec.MaxSize))
 	} else if ig.Spec.Role == kops.InstanceGroupRoleNode {
-		maxSize = fi.Int64(2)
+		maxSize = fi.PtrTo(int64(2))
 	}
 
 	t.MinSize = minSize
@@ -440,6 +442,10 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 		t.InstanceProtection = ig.Spec.InstanceProtection
 	}
 
+	if ig.Spec.CapacityRebalance != nil {
+		t.CapacityRebalance = ig.Spec.CapacityRebalance
+	}
+
 	t.LoadBalancers = []*awstasks.ClassicLoadBalancer{}
 	t.TargetGroups = []*awstasks.TargetGroup{}
 
@@ -451,6 +457,9 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 		if b.UseLoadBalancerForAPI() && ig.HasAPIServer() {
 			if b.UseNetworkLoadBalancer() {
 				t.TargetGroups = append(t.TargetGroups, b.LinkToTargetGroup("tcp"))
+				if b.Cluster.UsesNoneDNS() && ig.IsControlPlane() {
+					t.TargetGroups = append(t.TargetGroups, b.LinkToTargetGroup("kops-controller"))
+				}
 				if b.Cluster.Spec.API.LoadBalancer.SSLCertificate != "" {
 					t.TargetGroups = append(t.TargetGroups, b.LinkToTargetGroup("tls"))
 				}
@@ -460,7 +469,7 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 		}
 
 		if ig.Spec.Role == kops.InstanceGroupRoleBastion {
-			t.LoadBalancers = append(t.LoadBalancers, b.LinkToCLB("bastion"))
+			t.TargetGroups = append(t.TargetGroups, b.LinkToTargetGroup("bastion"))
 		}
 	}
 
@@ -470,25 +479,29 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 				Name:             extLB.LoadBalancerName,
 				Lifecycle:        b.Lifecycle,
 				LoadBalancerName: extLB.LoadBalancerName,
-				Shared:           fi.Bool(true),
+				Shared:           fi.PtrTo(true),
 			}
 			t.LoadBalancers = append(t.LoadBalancers, lb)
-			c.EnsureTask(lb)
+			if err := c.EnsureTask(lb); err != nil {
+				return nil, err
+			}
 		}
 
 		if extLB.TargetGroupARN != nil {
-			targetGroupName, err := awsup.GetTargetGroupNameFromARN(fi.StringValue(extLB.TargetGroupARN))
+			targetGroupName, err := awsup.GetTargetGroupNameFromARN(fi.ValueOf(extLB.TargetGroupARN))
 			if err != nil {
 				return nil, err
 			}
 			tg := &awstasks.TargetGroup{
-				Name:      fi.String(name + "-" + targetGroupName),
+				Name:      fi.PtrTo(targetGroupName),
 				Lifecycle: b.Lifecycle,
 				ARN:       extLB.TargetGroupARN,
-				Shared:    fi.Bool(true),
+				Shared:    fi.PtrTo(true),
 			}
 			t.TargetGroups = append(t.TargetGroups, tg)
-			c.AddTask(tg)
+			if err := c.EnsureTask(tg); err != nil {
+				return nil, err
+			}
 		}
 	}
 	sort.Stable(awstasks.OrderLoadBalancersByName(t.LoadBalancers))
@@ -513,7 +526,7 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 					ir.CPUMin = &cpuMin
 				}
 			} else {
-				ir.CPUMin = fi.Int64(0)
+				ir.CPUMin = fi.PtrTo(int64(0))
 			}
 
 			memory := spec.InstanceRequirements.Memory
@@ -527,7 +540,7 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 					ir.MemoryMin = &memoryMin
 				}
 			} else {
-				ir.MemoryMin = fi.Int64(0)
+				ir.MemoryMin = fi.PtrTo(int64(0))
 			}
 			t.InstanceRequirements = ir
 		}
@@ -540,7 +553,7 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 		t.MixedSpotInstancePools = spec.SpotInstancePools
 		// In order to unset maxprice, the value needs to be ""
 		if ig.Spec.MaxPrice == nil {
-			t.MixedSpotMaxPrice = fi.String("")
+			t.MixedSpotMaxPrice = fi.PtrTo("")
 		} else {
 			t.MixedSpotMaxPrice = ig.Spec.MaxPrice
 		}
@@ -548,9 +561,9 @@ func (b *AutoscalingGroupModelBuilder) buildAutoScalingGroupTask(c *fi.ModelBuil
 
 	if ig.Spec.MaxInstanceLifetime != nil {
 		lifetimeSec := int64(ig.Spec.MaxInstanceLifetime.Seconds())
-		t.MaxInstanceLifetime = fi.Int64(lifetimeSec)
+		t.MaxInstanceLifetime = fi.PtrTo(lifetimeSec)
 	} else {
-		t.MaxInstanceLifetime = fi.Int64(0)
+		t.MaxInstanceLifetime = fi.PtrTo(int64(0))
 	}
 	return t, nil
 }
