@@ -21,7 +21,7 @@ import (
 	"reflect"
 	"testing"
 
-	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2020-06-01/compute"
+	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2022-08-01/compute"
 	"github.com/Azure/go-autorest/autorest/to"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/model"
@@ -37,23 +37,23 @@ func TestVMScaleSetModelBuilder_Build(t *testing.T) {
 			Lifecycle: fi.LifecycleSync,
 			Cluster: &kops.Cluster{
 				Spec: kops.ClusterSpec{
-					Networking: &kops.NetworkingSpec{},
+					Networking: kops.NetworkingSpec{},
 				},
 			},
 		},
 	}
-	c := &fi.ModelBuilderContext{
-		Tasks: make(map[string]fi.Task),
+	c := &fi.CloudupModelBuilderContext{
+		Tasks: make(map[string]fi.CloudupTask),
 	}
 
 	caTask := &fitasks.Keypair{
-		Name:    fi.String(fi.CertificateIDCA),
+		Name:    fi.PtrTo(fi.CertificateIDCA),
 		Subject: "cn=kubernetes",
 		Type:    "ca",
 	}
 	c.AddTask(caTask)
 	etcdCaTask := &fitasks.Keypair{
-		Name:    fi.String("etcd-clients-ca"),
+		Name:    fi.PtrTo("etcd-clients-ca"),
 		Subject: "cn=etcd-clients-ca",
 		Type:    "ca",
 	}
@@ -63,7 +63,7 @@ func TestVMScaleSetModelBuilder_Build(t *testing.T) {
 		"kube-proxy",
 	} {
 		c.AddTask(&fitasks.Keypair{
-			Name:    fi.String(cert),
+			Name:    fi.PtrTo(cert),
 			Subject: "cn=" + cert,
 			Signer:  caTask,
 			Type:    "client",
@@ -84,16 +84,16 @@ func TestGetCapacity(t *testing.T) {
 	}{
 		{
 			spec: kops.InstanceGroupSpec{
-				Role:    kops.InstanceGroupRoleMaster,
-				MinSize: fi.Int32(3),
-				MaxSize: fi.Int32(3),
+				Role:    kops.InstanceGroupRoleControlPlane,
+				MinSize: fi.PtrTo(int32(3)),
+				MaxSize: fi.PtrTo(int32(3)),
 			},
 			success:  true,
 			capacity: 3,
 		},
 		{
 			spec: kops.InstanceGroupSpec{
-				Role: kops.InstanceGroupRoleMaster,
+				Role: kops.InstanceGroupRoleControlPlane,
 			},
 			success:  true,
 			capacity: 1,
@@ -107,9 +107,9 @@ func TestGetCapacity(t *testing.T) {
 		},
 		{
 			spec: kops.InstanceGroupSpec{
-				Role:    kops.InstanceGroupRoleMaster,
-				MinSize: fi.Int32(1),
-				MaxSize: fi.Int32(2),
+				Role:    kops.InstanceGroupRoleControlPlane,
+				MinSize: fi.PtrTo(int32(1)),
+				MaxSize: fi.PtrTo(int32(2)),
 			},
 			success: false,
 		},
@@ -143,8 +143,8 @@ func TestGetStorageProfile(t *testing.T) {
 		{
 			spec: kops.InstanceGroupSpec{
 				Image:          "Canonical:UbuntuServer:18.04-LTS:latest",
-				RootVolumeType: fi.String(string(compute.StorageAccountTypesStandardLRS)),
-				RootVolumeSize: fi.Int32(128),
+				RootVolumeType: fi.PtrTo(string(compute.StorageAccountTypesStandardLRS)),
+				RootVolumeSize: fi.PtrTo(int32(128)),
 			},
 			profile: &compute.VirtualMachineScaleSetStorageProfile{
 				ImageReference: &compute.ImageReference{
@@ -167,7 +167,7 @@ func TestGetStorageProfile(t *testing.T) {
 		{
 			spec: kops.InstanceGroupSpec{
 				Image: "Canonical:UbuntuServer:18.04-LTS:latest",
-				Role:  kops.InstanceGroupRoleMaster,
+				Role:  kops.InstanceGroupRoleControlPlane,
 			},
 			profile: &compute.VirtualMachineScaleSetStorageProfile{
 				ImageReference: &compute.ImageReference{
