@@ -35,7 +35,6 @@ import (
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/pkg/cloudinstances"
-	"k8s.io/kops/pkg/dns"
 )
 
 // ValidationCluster uses a cluster to validate.
@@ -125,16 +124,15 @@ func NewClusterValidator(cluster *kops.Cluster, cloud fi.Cloud, instanceGroupLis
 func (v *clusterValidatorImpl) Validate() (*ValidationCluster, error) {
 	ctx := context.TODO()
 
-	clusterName := v.cluster.Name
-	dnsProvider := kops.ExternalDNSProviderDNSController
-	if v.cluster.Spec.ExternalDNS != nil && v.cluster.Spec.ExternalDNS.Provider == kops.ExternalDNSProviderExternalDNS {
-		dnsProvider = kops.ExternalDNSProviderExternalDNS
-	}
-
 	validation := &ValidationCluster{}
 
-	// Do not use if we are running gossip
-	if !dns.IsGossipHostname(clusterName) {
+	// Do not use if we are running gossip or without dns
+	if !v.cluster.IsGossip() && !v.cluster.UsesNoneDNS() {
+		dnsProvider := kops.ExternalDNSProviderDNSController
+		if v.cluster.Spec.ExternalDNS != nil && v.cluster.Spec.ExternalDNS.Provider == kops.ExternalDNSProviderExternalDNS {
+			dnsProvider = kops.ExternalDNSProviderExternalDNS
+		}
+
 		hasPlaceHolderIPAddress, err := hasPlaceHolderIP(v.host)
 		if err != nil {
 			return nil, err
@@ -144,7 +142,7 @@ func (v *clusterValidatorImpl) Validate() (*ValidationCluster, error) {
 			message := fmt.Sprintf("Validation Failed\n\n"+
 				"The %[1]v Kubernetes deployment has not updated the Kubernetes cluster's API DNS entry to the correct IP address."+
 				"  The API DNS IP address is the placeholder address that kops creates: %[2]v."+
-				"  Please wait about 5-10 minutes for a master to start, %[1]v to launch, and DNS to propagate."+
+				"  Please wait about 5-10 minutes for a control plane node to start, %[1]v to launch, and DNS to propagate."+
 				"  The protokube container and %[1]v deployment logs may contain more diagnostic information."+
 				"  Etcd and the API DNS entries must be updated for a kops Kubernetes cluster to start.", dnsProvider, hasPlaceHolderIPAddress)
 			validation.addError(&ValidationError{
@@ -169,7 +167,7 @@ func (v *clusterValidatorImpl) Validate() (*ValidationCluster, error) {
 	readyNodes, nodeInstanceGroupMapping := validation.validateNodes(cloudGroups, v.instanceGroups)
 
 	if err := validation.collectPodFailures(ctx, v.k8sClient, readyNodes, nodeInstanceGroupMapping); err != nil {
-		return nil, fmt.Errorf("cannot get pod health for %q: %v", clusterName, err)
+		return nil, fmt.Errorf("cannot get pod health for %q: %v", v.cluster.Name, err)
 	}
 
 	return validation, nil
@@ -267,7 +265,7 @@ func (v *ValidationCluster) collectPodFailures(ctx context.Context, client kuber
 			v.addError(&ValidationError{
 				Kind:          "Node",
 				Name:          node,
-				Message:       fmt.Sprintf("master %q is missing %s pod", node, app),
+				Message:       fmt.Sprintf("control-plane node %q is missing %s pod", node, app),
 				InstanceGroup: nodeInstanceGroupMapping[node],
 			})
 		}
@@ -335,7 +333,7 @@ func (v *ValidationCluster) validateNodes(cloudGroups map[string]*cloudinstances
 
 			nodeInstanceGroupMapping[node.Name] = cloudGroup.InstanceGroup
 
-			role := strings.ToLower(string(cloudGroup.InstanceGroup.Spec.Role))
+			role := cloudGroup.InstanceGroup.Spec.Role.ToLowerString()
 			if role == "" {
 				role = "node"
 			}
@@ -357,7 +355,7 @@ func (v *ValidationCluster) validateNodes(cloudGroups map[string]*cloudinstances
 			}
 
 			switch n.Role {
-			case "master", "apiserver", "node":
+			case "control-plane", "apiserver", "node":
 				if !ready {
 					v.addError(&ValidationError{
 						Kind:          "Node",
