@@ -116,13 +116,17 @@ func (d *deployer) createCluster(zones []string, adminAccess string, yes bool) e
 		"--cloud", d.CloudProvider,
 		"--kubernetes-version", d.KubernetesVersion,
 		"--ssh-public-key", d.SSHPublicKeyPath,
-		"--override", "cluster.spec.nodePortAccess=0.0.0.0/0",
+		"--set", "cluster.spec.nodePortAccess=0.0.0.0/0",
 	}
 	if yes {
 		args = append(args, "--yes")
 	}
 
+	isArm := false
 	if d.CreateArgs != "" {
+		if strings.Contains(d.CreateArgs, "arm64") {
+			isArm = true
+		}
 		createArgs, err := shlex.Split(d.CreateArgs)
 		if err != nil {
 			return err
@@ -134,12 +138,16 @@ func (d *deployer) createCluster(zones []string, adminAccess string, yes bool) e
 	args = appendIfUnset(args, "--master-volume-size", "48")
 	args = appendIfUnset(args, "--node-count", "4")
 	args = appendIfUnset(args, "--node-volume-size", "48")
-	args = appendIfUnset(args, "--override", adminAccess)
+	args = appendIfUnset(args, "--set", adminAccess)
 	args = appendIfUnset(args, "--zones", strings.Join(zones, ","))
 
 	switch d.CloudProvider {
 	case "aws":
-		args = appendIfUnset(args, "--master-size", "c5.large")
+		if isArm {
+			args = appendIfUnset(args, "--master-size", "c6g.large")
+		} else {
+			args = appendIfUnset(args, "--master-size", "c5.large")
+		}
 	case "gce":
 		args = appendIfUnset(args, "--master-size", "e2-standard-2")
 		if d.GCPProject != "" {
@@ -286,7 +294,7 @@ func (d *deployer) zones() ([]string, error) {
 }
 
 // appendIfUnset will append an argument and its value to args if the arg is not already present
-// This shouldn't be used for arguments that can be specified multiple times like --override
+// This shouldn't be used for arguments that can be specified multiple times like --set
 func appendIfUnset(args []string, arg, value string) []string {
 	for _, existingArg := range args {
 		existingKey := strings.Split(existingArg, "=")
