@@ -23,7 +23,6 @@ import (
 	"k8s.io/apimachinery/pkg/util/validation/field"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -53,8 +52,8 @@ func (h *AutoscalingLifecycleHook) CompareWithID() *string {
 	return h.Name
 }
 
-func (h *AutoscalingLifecycleHook) Find(c *fi.Context) (*AutoscalingLifecycleHook, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (h *AutoscalingLifecycleHook) Find(c *fi.CloudupContext) (*AutoscalingLifecycleHook, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	request := &autoscaling.DescribeLifecycleHooksInput{
 		AutoScalingGroupName: h.AutoscalingGroup.Name,
@@ -66,7 +65,7 @@ func (h *AutoscalingLifecycleHook) Find(c *fi.Context) (*AutoscalingLifecycleHoo
 		return nil, fmt.Errorf("error listing ASG Lifecycle Hooks: %v", err)
 	}
 	if response == nil || len(response.LifecycleHooks) == 0 {
-		if !fi.BoolValue(h.Enabled) {
+		if !fi.ValueOf(h.Enabled) {
 			return h, nil
 		}
 
@@ -86,14 +85,14 @@ func (h *AutoscalingLifecycleHook) Find(c *fi.Context) (*AutoscalingLifecycleHoo
 		DefaultResult:       hook.DefaultResult,
 		HeartbeatTimeout:    hook.HeartbeatTimeout,
 		LifecycleTransition: hook.LifecycleTransition,
-		Enabled:             fi.Bool(true),
+		Enabled:             fi.PtrTo(true),
 	}
 
 	return actual, nil
 }
 
-func (h *AutoscalingLifecycleHook) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(h, c)
+func (h *AutoscalingLifecycleHook) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(h, c)
 }
 
 func (_ *AutoscalingLifecycleHook) CheckChanges(a, e, changes *AutoscalingLifecycleHook) error {
@@ -111,7 +110,7 @@ func (_ *AutoscalingLifecycleHook) CheckChanges(a, e, changes *AutoscalingLifecy
 
 func (*AutoscalingLifecycleHook) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *AutoscalingLifecycleHook) error {
 	if changes != nil {
-		if fi.BoolValue(e.Enabled) {
+		if fi.ValueOf(e.Enabled) {
 			request := &autoscaling.PutLifecycleHookInput{
 				AutoScalingGroupName: e.AutoscalingGroup.Name,
 				DefaultResult:        e.DefaultResult,
@@ -147,7 +146,7 @@ type terraformASGLifecycleHook struct {
 }
 
 func (_ *AutoscalingLifecycleHook) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *AutoscalingLifecycleHook) error {
-	if !fi.BoolValue(e.Enabled) {
+	if !fi.ValueOf(e.Enabled) {
 		return nil
 	}
 	tf := &terraformASGLifecycleHook{
@@ -161,29 +160,6 @@ func (_ *AutoscalingLifecycleHook) RenderTerraform(t *terraform.TerraformTarget,
 	return t.RenderResource("aws_autoscaling_lifecycle_hook", *e.Name, tf)
 }
 
-type cloudformationASGLifecycleHook struct {
-	LifecycleHookName    *string
-	AutoScalingGroupName *cloudformation.Literal
-	DefaultResult        *string
-	HeartbeatTimeout     *int64
-	LifecycleTransition  *string
-}
-
-func (_ *AutoscalingLifecycleHook) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *AutoscalingLifecycleHook) error {
-	if !fi.BoolValue(e.Enabled) {
-		return nil
-	}
-	tf := &cloudformationASGLifecycleHook{
-		LifecycleHookName:    e.GetHookName(),
-		AutoScalingGroupName: e.AutoscalingGroup.CloudformationLink(),
-		DefaultResult:        e.DefaultResult,
-		HeartbeatTimeout:     e.HeartbeatTimeout,
-		LifecycleTransition:  e.LifecycleTransition,
-	}
-
-	return t.RenderResource("AWS::AutoScaling::LifecycleHook", *e.Name, tf)
-}
-
 func (h *AutoscalingLifecycleHook) GetHookName() *string {
 	if h.HookName != nil {
 		return h.HookName
