@@ -24,12 +24,12 @@ import (
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/awserr"
+	"github.com/aws/aws-sdk-go/service/elb"
 	"github.com/aws/aws-sdk-go/service/elbv2"
 	"github.com/aws/aws-sdk-go/service/route53"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -48,6 +48,7 @@ type NetworkLoadBalancer struct {
 	// (NLB is restricted as to names, so we have limited choices!)
 	// We use the Name tag to find the existing NLB.
 	LoadBalancerName *string
+	CLBName          *string
 
 	DNSName      *string
 	HostedZoneId *string
@@ -73,6 +74,8 @@ type NetworkLoadBalancer struct {
 }
 
 var _ fi.CompareWithID = &NetworkLoadBalancer{}
+var _ fi.CloudupTaskNormalize = &NetworkLoadBalancer{}
+var _ fi.CloudupProducesDeletions = &NetworkLoadBalancer{}
 
 func (e *NetworkLoadBalancer) CompareWithID() *string {
 	return e.Name
@@ -88,8 +91,8 @@ type NetworkLoadBalancerListener struct {
 func (e *NetworkLoadBalancerListener) mapToAWS(targetGroups []*TargetGroup, loadBalancerArn string) (*elbv2.CreateListenerInput, error) {
 	var tgARN string
 	for _, tg := range targetGroups {
-		if fi.StringValue(tg.Name) == e.TargetGroupName {
-			tgARN = fi.StringValue(tg.ARN)
+		if fi.ValueOf(tg.Name) == e.TargetGroupName {
+			tgARN = fi.ValueOf(tg.ARN)
 		}
 	}
 	if tgARN == "" {
@@ -123,9 +126,9 @@ func (e *NetworkLoadBalancerListener) mapToAWS(targetGroups []*TargetGroup, load
 	return l, nil
 }
 
-var _ fi.HasDependencies = &NetworkLoadBalancerListener{}
+var _ fi.CloudupHasDependencies = &NetworkLoadBalancerListener{}
 
-func (e *NetworkLoadBalancerListener) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (e *NetworkLoadBalancerListener) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
 	return nil
 }
 
@@ -238,8 +241,8 @@ func (e *NetworkLoadBalancer) getHostedZoneId() *string {
 	return e.HostedZoneId
 }
 
-func (e *NetworkLoadBalancer) Find(c *fi.Context) (*NetworkLoadBalancer, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *NetworkLoadBalancer) Find(c *fi.CloudupContext) (*NetworkLoadBalancer, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	lb, err := cloud.FindELBV2ByNameTag(e.Tags["Name"])
 	if err != nil {
@@ -253,6 +256,7 @@ func (e *NetworkLoadBalancer) Find(c *fi.Context) (*NetworkLoadBalancer, error)
 
 	actual := &NetworkLoadBalancer{}
 	actual.Name = e.Name
+	actual.CLBName = e.CLBName
 	actual.LoadBalancerName = lb.LoadBalancerName
 	actual.DNSName = lb.DNSName
 	actual.HostedZoneId = lb.CanonicalHostedZoneId // CanonicalHostedZoneNameID
@@ -319,13 +323,13 @@ func (e *NetworkLoadBalancer) Find(c *fi.Context) (*NetworkLoadBalancer, error)
 			if len(l.DefaultActions) > 0 {
 				targetGroupARN := l.DefaultActions[0].TargetGroupArn
 				if targetGroupARN != nil {
-					targetGroupName, err := awsup.GetTargetGroupNameFromARN(fi.StringValue(targetGroupARN))
+					targetGroupName, err := awsup.GetTargetGroupNameFromARN(fi.ValueOf(targetGroupARN))
 					if err != nil {
 						return nil, err
 					}
-					actual.TargetGroups = append(actual.TargetGroups, &TargetGroup{ARN: targetGroupARN, Name: fi.String(targetGroupName)})
+					actual.TargetGroups = append(actual.TargetGroups, &TargetGroup{ARN: targetGroupARN, Name: fi.PtrTo(targetGroupName)})
 
-					cloud := c.Cloud.(awsup.AWSCloud)
+					cloud := c.T.Cloud.(awsup.AWSCloud)
 					descResp, err := cloud.ELBV2().DescribeTargetGroups(&elbv2.DescribeTargetGroupsInput{
 						TargetGroupArns: []*string{targetGroupARN},
 					})
@@ -362,7 +366,7 @@ func (e *NetworkLoadBalancer) Find(c *fi.Context) (*NetworkLoadBalancer, error)
 				if err != nil {
 					return nil, err
 				}
-				actual.CrossZoneLoadBalancing = fi.Bool(b)
+				actual.CrossZoneLoadBalancing = fi.PtrTo(b)
 			case "access_logs.s3.enabled":
 				b, err := strconv.ParseBool(*value)
 				if err != nil {
@@ -371,19 +375,19 @@ func (e *NetworkLoadBalancer) Find(c *fi.Context) (*NetworkLoadBalancer, error)
 				if actual.AccessLog == nil {
 					actual.AccessLog = &NetworkLoadBalancerAccessLog{}
 				}
-				actual.AccessLog.Enabled = fi.Bool(b)
+				actual.AccessLog.Enabled = fi.PtrTo(b)
 			case "access_logs.s3.bucket":
 				if actual.AccessLog == nil {
 					actual.AccessLog = &NetworkLoadBalancerAccessLog{}
 				}
-				if fi.StringValue(value) != "" {
+				if fi.ValueOf(value) != "" {
 					actual.AccessLog.S3BucketName = value
 				}
 			case "access_logs.s3.prefix":
 				if actual.AccessLog == nil {
 					actual.AccessLog = &NetworkLoadBalancerAccessLog{}
 				}
-				if fi.StringValue(value) != "" {
+				if fi.ValueOf(value) != "" {
 					actual.AccessLog.S3BucketPrefix = value
 				}
 			default:
@@ -407,19 +411,18 @@ func (e *NetworkLoadBalancer) Find(c *fi.Context) (*NetworkLoadBalancer, error)
 	}
 
 	// An existing internal NLB can't be updated to dualstack.
-	if fi.StringValue(actual.Scheme) == elbv2.LoadBalancerSchemeEnumInternal && fi.StringValue(actual.IpAddressType) == elbv2.IpAddressTypeIpv4 {
+	if fi.ValueOf(actual.Scheme) == elbv2.LoadBalancerSchemeEnumInternal && fi.ValueOf(actual.IpAddressType) == elbv2.IpAddressTypeIpv4 {
 		e.IpAddressType = actual.IpAddressType
 	}
 
 	// We allow for the LoadBalancerName to be wrong:
 	// 1. We don't want to force a rename of the NLB, because that is a destructive operation
-	if fi.StringValue(e.LoadBalancerName) != fi.StringValue(actual.LoadBalancerName) {
+	if fi.ValueOf(e.LoadBalancerName) != fi.ValueOf(actual.LoadBalancerName) {
 		klog.V(2).Infof("Reusing existing load balancer with name: %q", aws.StringValue(actual.LoadBalancerName))
 		e.LoadBalancerName = actual.LoadBalancerName
 	}
 
-	// TODO: Make Normalize a standard method
-	actual.Normalize()
+	_ = actual.Normalize(c)
 	actual.ForAPIServer = e.ForAPIServer
 	actual.Lifecycle = e.Lifecycle
 
@@ -434,41 +437,54 @@ func (e *NetworkLoadBalancer) IsForAPIServer() bool {
 	return e.ForAPIServer
 }
 
-func (e *NetworkLoadBalancer) FindAddresses(context *fi.Context) ([]string, error) {
-	cloud := context.Cloud.(awsup.AWSCloud)
+func (e *NetworkLoadBalancer) FindAddresses(context *fi.CloudupContext) ([]string, error) {
+	var addresses []string
 
-	lb, err := cloud.FindELBV2ByNameTag(e.Tags["Name"])
-	if err != nil {
-		return nil, err
-	}
-	if lb == nil {
-		return nil, nil
+	cloud := context.T.Cloud.(awsup.AWSCloud)
+	cluster := context.T.Cluster
+
+	{
+		lb, err := cloud.FindELBV2ByNameTag(e.Tags["Name"])
+		if err != nil {
+			return nil, fmt.Errorf("failed to find load balancer matching %q: %w", e.Tags["Name"], err)
+		}
+		if lb != nil && fi.ValueOf(lb.DNSName) != "" {
+			addresses = append(addresses, fi.ValueOf(lb.DNSName))
+		}
 	}
 
-	lbDnsName := fi.StringValue(lb.DNSName)
-	if lbDnsName == "" {
-		return nil, nil
+	if cluster.UsesNoneDNS() {
+		nis, err := cloud.FindELBV2NetworkInterfacesByName(fi.ValueOf(e.VPC.ID), fi.ValueOf(e.LoadBalancerName))
+		if err != nil {
+			return nil, fmt.Errorf("failed to find network interfaces matching %q: %w", fi.ValueOf(e.LoadBalancerName), err)
+		}
+		for _, ni := range nis {
+			if fi.ValueOf(ni.PrivateIpAddress) != "" {
+				addresses = append(addresses, fi.ValueOf(ni.PrivateIpAddress))
+			}
+		}
 	}
-	return []string{lbDnsName}, nil
+
+	sort.Strings(addresses)
+
+	return addresses, nil
 }
 
-func (e *NetworkLoadBalancer) Run(c *fi.Context) error {
-	// TODO: Make Normalize a standard method
-	e.Normalize()
-
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *NetworkLoadBalancer) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
-func (e *NetworkLoadBalancer) Normalize() {
+func (e *NetworkLoadBalancer) Normalize(c *fi.CloudupContext) error {
 	// We need to sort our arrays consistently, so we don't get spurious changes
 	sort.Stable(OrderSubnetMappingsByName(e.SubnetMappings))
 	sort.Stable(OrderListenersByPort(e.Listeners))
 	sort.Stable(OrderTargetGroupsByName(e.TargetGroups))
+	return nil
 }
 
 func (*NetworkLoadBalancer) CheckChanges(a, e, changes *NetworkLoadBalancer) error {
 	if a == nil {
-		if fi.StringValue(e.Name) == "" {
+		if fi.ValueOf(e.Name) == "" {
 			return fi.RequiredField("Name")
 		}
 		if len(e.SubnetMappings) == 0 {
@@ -509,7 +525,7 @@ func (*NetworkLoadBalancer) CheckChanges(a, e, changes *NetworkLoadBalancer) err
 				if !ok {
 					return fmt.Errorf("network load balancers do not support detaching subnets")
 				}
-				if fi.StringValue(eIP) != fi.StringValue(s.PrivateIPv4Address) || fi.StringValue(eIP) != fi.StringValue(s.AllocationID) {
+				if fi.ValueOf(eIP) != fi.ValueOf(s.PrivateIPv4Address) || fi.ValueOf(eIP) != fi.ValueOf(s.AllocationID) {
 					return fmt.Errorf("network load balancers do not support modifying address settings")
 				}
 			}
@@ -538,37 +554,53 @@ func (_ *NetworkLoadBalancer) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Ne
 
 		loadBalancerName = *e.LoadBalancerName
 
-		request := &elbv2.CreateLoadBalancerInput{}
-		request.Name = e.LoadBalancerName
-		request.Scheme = e.Scheme
-		request.Type = e.Type
-		request.IpAddressType = e.IpAddressType
-		request.Tags = awsup.ELBv2Tags(e.Tags)
-
-		for _, subnetMapping := range e.SubnetMappings {
-			request.SubnetMappings = append(request.SubnetMappings, &elbv2.SubnetMapping{
-				SubnetId:           subnetMapping.Subnet.ID,
-				AllocationId:       subnetMapping.AllocationID,
-				PrivateIPv4Address: subnetMapping.PrivateIPv4Address,
-			})
-		}
-
 		{
-			klog.V(2).Infof("Creating NLB with Name:%q", loadBalancerName)
+			request := &elbv2.CreateLoadBalancerInput{}
+			request.Name = e.LoadBalancerName
+			request.Scheme = e.Scheme
+			request.Type = e.Type
+			request.IpAddressType = e.IpAddressType
+			request.Tags = awsup.ELBv2Tags(e.Tags)
+
+			for _, subnetMapping := range e.SubnetMappings {
+				request.SubnetMappings = append(request.SubnetMappings, &elbv2.SubnetMapping{
+					SubnetId:           subnetMapping.Subnet.ID,
+					AllocationId:       subnetMapping.AllocationID,
+					PrivateIPv4Address: subnetMapping.PrivateIPv4Address,
+				})
+			}
+
+			klog.V(2).Infof("Creating NLB %q", loadBalancerName)
 
 			response, err := t.Cloud.ELBV2().CreateLoadBalancer(request)
 			if err != nil {
-				return fmt.Errorf("error creating NLB: %v", err)
+				return fmt.Errorf("error creating NLB %q: %w", loadBalancerName, err)
+			}
+			if len(response.LoadBalancers) != 1 {
+				return fmt.Errorf("error creating NLB %q: found %d", loadBalancerName, len(response.LoadBalancers))
 			}
 
-			if len(response.LoadBalancers) != 1 {
-				return fmt.Errorf("Either too many or too few NLBs were created, wanted to find %q", loadBalancerName)
-			} else {
-				lb := response.LoadBalancers[0]
-				e.DNSName = lb.DNSName
-				e.HostedZoneId = lb.CanonicalHostedZoneId
-				e.VPC = &VPC{ID: lb.VpcId}
-				loadBalancerArn = fi.StringValue(lb.LoadBalancerArn)
+			lb := response.LoadBalancers[0]
+			e.DNSName = lb.DNSName
+			e.HostedZoneId = lb.CanonicalHostedZoneId
+			e.VPC = &VPC{ID: lb.VpcId}
+			loadBalancerArn = fi.ValueOf(lb.LoadBalancerArn)
+
+		}
+
+		// Wait for all load balancer components to be created (including network interfaces needed for NoneDNS).
+		// Limiting this to clusters using NoneDNS because load balancer creation is quite slow.
+		for _, tg := range e.TargetGroups {
+			if strings.HasPrefix(fi.ValueOf(tg.Name), "kops-controller") {
+				klog.Infof("Waiting for load balancer %q to be created...", loadBalancerName)
+				request := &elbv2.DescribeLoadBalancersInput{
+					Names: []*string{&loadBalancerName},
+				}
+				err := t.Cloud.ELBV2().WaitUntilLoadBalancerAvailable(request)
+				if err != nil {
+					return fmt.Errorf("error waiting for NLB %q: %w", loadBalancerName, err)
+				}
+				break
 			}
 		}
 
@@ -587,14 +619,14 @@ func (_ *NetworkLoadBalancer) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Ne
 			}
 		}
 	} else {
-		loadBalancerName = fi.StringValue(a.LoadBalancerName)
+		loadBalancerName = fi.ValueOf(a.LoadBalancerName)
 
 		lb, err := findNetworkLoadBalancerByLoadBalancerName(t.Cloud, loadBalancerName)
 		if err != nil {
 			return fmt.Errorf("error getting load balancer by name: %v", err)
 		}
 
-		loadBalancerArn = fi.StringValue(lb.LoadBalancerArn)
+		loadBalancerArn = fi.ValueOf(lb.LoadBalancerArn)
 
 		if changes.IpAddressType != nil {
 			request := &elbv2.SetIpAddressTypeInput{
@@ -622,7 +654,7 @@ func (_ *NetworkLoadBalancer) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Ne
 			hasChanges := false
 			for _, s := range e.SubnetMappings {
 				aIP, ok := actualSubnets[*s.Subnet.ID]
-				if !ok || (fi.StringValue(s.PrivateIPv4Address) != fi.StringValue(aIP) && fi.StringValue(s.AllocationID) != fi.StringValue(aIP)) {
+				if !ok || (fi.ValueOf(s.PrivateIPv4Address) != fi.ValueOf(aIP) && fi.ValueOf(s.AllocationID) != fi.ValueOf(aIP)) {
 					hasChanges = true
 				}
 				awsSubnetMappings = append(awsSubnetMappings, &elbv2.SubnetMapping{
@@ -731,10 +763,10 @@ type terraformNetworkLoadBalancerListenerAction struct {
 func (_ *NetworkLoadBalancer) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *NetworkLoadBalancer) error {
 	nlbTF := &terraformNetworkLoadBalancer{
 		Name:                   *e.LoadBalancerName,
-		Internal:               fi.StringValue(e.Scheme) == elbv2.LoadBalancerSchemeEnumInternal,
+		Internal:               fi.ValueOf(e.Scheme) == elbv2.LoadBalancerSchemeEnumInternal,
 		Type:                   elbv2.LoadBalancerTypeEnumNetwork,
 		Tags:                   e.Tags,
-		CrossZoneLoadBalancing: fi.BoolValue(e.CrossZoneLoadBalancing),
+		CrossZoneLoadBalancing: fi.ValueOf(e.CrossZoneLoadBalancing),
 	}
 
 	for _, subnetMapping := range e.SubnetMappings {
@@ -745,7 +777,7 @@ func (_ *NetworkLoadBalancer) RenderTerraform(t *terraform.TerraformTarget, a, e
 		})
 	}
 
-	if e.AccessLog != nil && fi.BoolValue(e.AccessLog.Enabled) {
+	if e.AccessLog != nil && fi.ValueOf(e.AccessLog.Enabled) {
 		nlbTF.AccessLog = &terraformNetworkLoadBalancerAccessLog{
 			Enabled:        e.AccessLog.Enabled,
 			S3BucketName:   e.AccessLog.S3BucketName,
@@ -806,136 +838,63 @@ func (e *NetworkLoadBalancer) TerraformLink(params ...string) *terraformWriter.L
 	return terraformWriter.LiteralProperty("aws_lb", *e.Name, prop)
 }
 
-type cloudformationNetworkLoadBalancer struct {
-	Name                   string                                `json:"Name"`
-	Scheme                 string                                `json:"Scheme"`
-	SubnetMappings         []*cloudformationSubnetMapping        `json:"SubnetMappings"`
-	Type                   string                                `json:"Type"`
-	Tags                   []cloudformationTag                   `json:"Tags"`
-	LoadBalancerAttributes []cloudformationLoadBalancerAttribute `json:"LoadBalancerAttributes,omitempty"`
-}
-
-type cloudformationSubnetMapping struct {
-	Subnet             *cloudformation.Literal `json:"SubnetId"`
-	AllocationId       *string                 `json:"AllocationId,omitempty"`
-	PrivateIPv4Address *string                 `json:"PrivateIPv4Address,omitempty"`
-}
-
-type cloudformationLoadBalancerAttribute struct {
-	Key   *string `json:"Key"`
-	Value *string `json:"Value,omitempty"`
-}
-
-type cloudformationNetworkLoadBalancerListener struct {
-	Certificates    []cloudformationNetworkLoadBalancerListenerCertificate `json:"Certificates,omitempty"`
-	DefaultActions  []cloudformationNetworkLoadBalancerListenerAction      `json:"DefaultActions"`
-	LoadBalancerARN *cloudformation.Literal                                `json:"LoadBalancerArn"`
-	Port            int64                                                  `json:"Port"`
-	Protocol        string                                                 `json:"Protocol"`
-	SSLPolicy       *string                                                `json:"SslPolicy,omitempty"`
-}
-
-type cloudformationNetworkLoadBalancerListenerCertificate struct {
-	CertificateArn string `json:"CertificateArn"`
-}
-
-type cloudformationNetworkLoadBalancerListenerAction struct {
-	Type           string                  `json:"Type"`
-	TargetGroupARN *cloudformation.Literal `json:"TargetGroupArn"`
-}
-
-func (_ *NetworkLoadBalancer) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *NetworkLoadBalancer) error {
-	nlbCF := &cloudformationNetworkLoadBalancer{
-		Name: *e.LoadBalancerName,
-		Type: elbv2.LoadBalancerTypeEnumNetwork,
-		Tags: buildCloudformationTags(e.Tags),
-	}
-	for _, subnetMapping := range e.SubnetMappings {
-		nlbCF.SubnetMappings = append(nlbCF.SubnetMappings, &cloudformationSubnetMapping{
-			Subnet:             subnetMapping.Subnet.CloudformationLink(),
-			AllocationId:       subnetMapping.AllocationID,
-			PrivateIPv4Address: subnetMapping.PrivateIPv4Address,
-		})
-	}
-	if e.Scheme != nil {
-		nlbCF.Scheme = *e.Scheme
-	} else {
-		nlbCF.Scheme = elbv2.LoadBalancerSchemeEnumInternetFacing
+// FindDeletions schedules deletion of the corresponding legacy classic load balancer when it no longer has targets.
+func (e *NetworkLoadBalancer) FindDeletions(context *fi.CloudupContext) ([]fi.CloudupDeletion, error) {
+	if e.CLBName == nil {
+		return nil, nil
 	}
 
-	if e.AccessLog != nil && *e.AccessLog.Enabled {
-		var attributes []cloudformationLoadBalancerAttribute
+	cloud := context.T.Cloud.(awsup.AWSCloud)
 
-		attributes = append(attributes, cloudformationLoadBalancerAttribute{
-			Key:   aws.String("access_logs.s3.enabled"),
-			Value: aws.String(strconv.FormatBool(aws.BoolValue(e.AccessLog.Enabled))),
-		})
-		attributes = append(attributes, cloudformationLoadBalancerAttribute{
-			Key:   aws.String("access_logs.s3.bucket"),
-			Value: e.AccessLog.S3BucketName,
-		})
-		attributes = append(attributes, cloudformationLoadBalancerAttribute{
-			Key:   aws.String("access_logs.s3.prefix"),
-			Value: e.AccessLog.S3BucketPrefix,
-		})
-		nlbCF.LoadBalancerAttributes = attributes
-	}
-
-	err := t.RenderResource("AWS::ElasticLoadBalancingV2::LoadBalancer", *e.Name, nlbCF)
+	lb, err := cloud.FindELBByNameTag(fi.ValueOf(e.CLBName))
 	if err != nil {
-		return err
+		return nil, err
+	}
+	if lb == nil {
+		return nil, nil
 	}
 
-	for _, listener := range e.Listeners {
-		var listenerTG *TargetGroup
-		for _, tg := range e.TargetGroups {
-			if aws.StringValue(tg.Name) == listener.TargetGroupName {
-				listenerTG = tg
-				break
-			}
-		}
-		if listenerTG == nil {
-			return fmt.Errorf("target group not found for NLB listener %+v", e)
-		}
-		listenerCF := &cloudformationNetworkLoadBalancerListener{
-			LoadBalancerARN: e.CloudformationLink(),
-			Port:            int64(listener.Port),
-			DefaultActions: []cloudformationNetworkLoadBalancerListenerAction{
-				{
-					Type:           elbv2.ActionTypeEnumForward,
-					TargetGroupARN: listenerTG.CloudformationLink(),
-				},
-			},
-		}
-		if listener.SSLCertificateID != "" {
-			listenerCF.Certificates = []cloudformationNetworkLoadBalancerListenerCertificate{
-				{CertificateArn: listener.SSLCertificateID},
-			}
-			listenerCF.Protocol = elbv2.ProtocolEnumTls
-			if listener.SSLPolicy != "" {
-				listenerCF.SSLPolicy = &listener.SSLPolicy
-			}
-		} else {
-			listenerCF.Protocol = elbv2.ProtocolEnumTcp
-		}
+	// Testing shows that the instances are deregistered immediately after the apply_cluster.
+	// TODO: Figure out how to delay deregistration until instances are terminated.
+	//if len(lb.Instances) > 0 {
+	//	klog.V(2).Infof("CLB %s has targets; not scheduling deletion", *lb.LoadBalancerName)
+	//	return nil, nil
+	//}
 
-		err = t.RenderResource("AWS::ElasticLoadBalancingV2::Listener", fmt.Sprintf("%v-%v", *e.Name, listener.Port), listenerCF)
-		if err != nil {
-			return err
-		}
+	actual := &deleteClassicLoadBalancer{}
+	actual.LoadBalancerName = lb.LoadBalancerName
+
+	klog.V(4).Infof("Found CLB %+v", actual)
+
+	return []fi.CloudupDeletion{actual}, nil
+}
+
+type deleteClassicLoadBalancer struct {
+	// LoadBalancerName is the name in ELB, possibly different from our name
+	// (ELB is restricted as to names, so we have limited choices!)
+	LoadBalancerName *string
+}
+
+func (d deleteClassicLoadBalancer) Delete(t fi.CloudupTarget) error {
+	awsTarget, ok := t.(*awsup.AWSAPITarget)
+	if !ok {
+		return fmt.Errorf("unexpected target type for deletion: %T", t)
+	}
+
+	_, err := awsTarget.Cloud.ELB().DeleteLoadBalancer(&elb.DeleteLoadBalancerInput{
+		LoadBalancerName: d.LoadBalancerName,
+	})
+	if err != nil {
+		return fmt.Errorf("deleting classic LoadBalancer: %w", err)
 	}
 
 	return nil
 }
 
-func (e *NetworkLoadBalancer) CloudformationLink() *cloudformation.Literal {
-	return cloudformation.Ref("AWS::ElasticLoadBalancingV2::LoadBalancer", *e.Name)
+func (d deleteClassicLoadBalancer) TaskName() string {
+	return "ClassicLoadBalancer"
 }
 
-func (e *NetworkLoadBalancer) CloudformationAttrCanonicalHostedZoneNameID() *cloudformation.Literal {
-	return cloudformation.GetAtt("AWS::ElasticLoadBalancingV2::LoadBalancer", *e.Name, "CanonicalHostedZoneID")
-}
-
-func (e *NetworkLoadBalancer) CloudformationAttrDNSName() *cloudformation.Literal {
-	return cloudformation.GetAtt("AWS::ElasticLoadBalancingV2::LoadBalancer", *e.Name, "DNSName")
+func (d deleteClassicLoadBalancer) Item() string {
+	return *d.LoadBalancerName
 }
