@@ -20,10 +20,8 @@ import (
 	"fmt"
 
 	"github.com/aws/aws-sdk-go/service/autoscaling"
-	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 )
 
@@ -45,8 +43,8 @@ type WarmPool struct {
 }
 
 // Find is used to discover the ASG in the cloud provider.
-func (e *WarmPool) Find(c *fi.Context) (*WarmPool, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *WarmPool) Find(c *fi.CloudupContext) (*WarmPool, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 	svc := cloud.Autoscaling()
 	warmPool, err := svc.DescribeWarmPool(&autoscaling.DescribeWarmPoolInput{
 		AutoScalingGroupName: e.Name,
@@ -61,22 +59,22 @@ func (e *WarmPool) Find(c *fi.Context) (*WarmPool, error) {
 		return &WarmPool{
 			Name:      e.Name,
 			Lifecycle: e.Lifecycle,
-			Enabled:   fi.Bool(false),
+			Enabled:   fi.PtrTo(false),
 		}, nil
 	}
 
 	actual := &WarmPool{
 		Name:      e.Name,
 		Lifecycle: e.Lifecycle,
-		Enabled:   fi.Bool(true),
+		Enabled:   fi.PtrTo(true),
 		MaxSize:   warmPool.WarmPoolConfiguration.MaxGroupPreparedCapacity,
-		MinSize:   fi.Int64Value(warmPool.WarmPoolConfiguration.MinSize),
+		MinSize:   fi.ValueOf(warmPool.WarmPoolConfiguration.MinSize),
 	}
 	return actual, nil
 }
 
-func (e *WarmPool) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *WarmPool) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (*WarmPool) CheckChanges(a, e, changes *WarmPool) error {
@@ -86,16 +84,16 @@ func (*WarmPool) CheckChanges(a, e, changes *WarmPool) error {
 func (*WarmPool) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *WarmPool) error {
 	svc := t.Cloud.Autoscaling()
 	if changes != nil {
-		if fi.BoolValue(e.Enabled) {
+		if fi.ValueOf(e.Enabled) {
 			minSize := e.MinSize
 			maxSize := e.MaxSize
 			if maxSize == nil {
-				maxSize = fi.Int64(-1)
+				maxSize = fi.PtrTo(int64(-1))
 			}
 			request := &autoscaling.PutWarmPoolInput{
 				AutoScalingGroupName:     e.Name,
 				MaxGroupPreparedCapacity: maxSize,
-				MinSize:                  fi.Int64(minSize),
+				MinSize:                  fi.PtrTo(minSize),
 			}
 
 			_, err := svc.PutWarmPool(request)
@@ -109,7 +107,7 @@ func (*WarmPool) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *WarmPool) error
 			_, err := svc.DeleteWarmPool(&autoscaling.DeleteWarmPoolInput{
 				AutoScalingGroupName: e.Name,
 				// We don't need to do any cleanup so, the faster the better
-				ForceDelete: fi.Bool(true),
+				ForceDelete: fi.PtrTo(true),
 			})
 			if err != nil {
 				return fmt.Errorf("error deleting warm pool: %w", err)
@@ -119,16 +117,7 @@ func (*WarmPool) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *WarmPool) error
 	return nil
 }
 
+// For the terraform target, warmpool config is rendered inside the AutoscalingGroup resource
 func (_ *WarmPool) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *WarmPool) error {
-	if changes != nil {
-		klog.Warning("ASG warm pool is not supported by the terraform target")
-	}
-	return nil
-}
-
-func (_ *WarmPool) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *WarmPool) error {
-	if changes != nil {
-		klog.Warning("ASG warm pool is not supported by the cloudformation target")
-	}
 	return nil
 }
