@@ -28,16 +28,16 @@ func addCiliumAddon(b *BootstrapChannelBuilder, addons *AddonList) error {
 
 		{
 			id := "k8s-1.16"
-			location := key + "/" + id + "-v1.11.yaml"
+			location := key + "/" + id + "-v1.12.yaml"
 
 			addon := &api.AddonSpec{
-				Name:               fi.String(key),
+				Name:               fi.PtrTo(key),
 				Selector:           networkingSelector(),
-				Manifest:           fi.String(location),
+				Manifest:           fi.PtrTo(location),
 				Id:                 id,
-				NeedsRollingUpdate: "all",
+				NeedsRollingUpdate: api.NeedsRollingUpdateAll,
 			}
-			if cilium.Hubble != nil && fi.BoolValue(cilium.Hubble.Enabled) {
+			if cilium.Hubble != nil && fi.ValueOf(cilium.Hubble.Enabled) {
 				addon.NeedsPKI = true
 			}
 			addons.Add(addon)
