@@ -42,8 +42,8 @@ func (e *Address) CompareWithID() *string {
 	return e.Name
 }
 
-func (e *Address) Find(c *fi.Context) (*Address, error) {
-	actual, err := e.find(c.Cloud.(gce.GCECloud))
+func (e *Address) Find(c *fi.CloudupContext) (*Address, error) {
+	actual, err := e.find(c.T.Cloud.(gce.GCECloud))
 	if actual != nil && err == nil {
 		if e.IPAddress == nil {
 			e.IPAddress = actual.IPAddress
@@ -100,19 +100,19 @@ func (e *Address) IsForAPIServer() bool {
 	return e.ForAPIServer
 }
 
-func (e *Address) FindAddresses(context *fi.Context) ([]string, error) {
-	actual, err := e.find(context.Cloud.(gce.GCECloud))
+func (e *Address) FindAddresses(context *fi.CloudupContext) ([]string, error) {
+	actual, err := e.find(context.T.Cloud.(gce.GCECloud))
 	if err != nil {
 		return nil, fmt.Errorf("error querying for IP Address: %v", err)
 	}
 	if actual == nil {
 		return nil, nil
 	}
-	return []string{fi.StringValue(actual.IPAddress)}, nil
+	return []string{fi.ValueOf(actual.IPAddress)}, nil
 }
 
-func (e *Address) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *Address) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (_ *Address) CheckChanges(a, e, changes *Address) error {
@@ -131,7 +131,7 @@ func (_ *Address) RenderGCE(t *gce.GCEAPITarget, a, e, changes *Address) error {
 	cloud := t.Cloud
 	addr := &compute.Address{
 		Name:    *e.Name,
-		Address: fi.StringValue(e.IPAddress),
+		Address: fi.ValueOf(e.IPAddress),
 		Region:  cloud.Region(),
 	}
 
@@ -165,7 +165,7 @@ func (_ *Address) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *A
 }
 
 func (e *Address) TerraformAddress() *terraformWriter.Literal {
-	name := fi.StringValue(e.Name)
+	name := fi.ValueOf(e.Name)
 
 	return terraformWriter.LiteralProperty("google_compute_address", name, "address")
 }
