@@ -62,8 +62,8 @@ func (e *Instance) CompareWithID() *string {
 	return e.Name
 }
 
-func (e *Instance) Find(c *fi.Context) (*Instance, error) {
-	cloud := c.Cloud.(gce.GCECloud)
+func (e *Instance) Find(c *fi.CloudupContext) (*Instance, error) {
+	cloud := c.T.Cloud.(gce.GCECloud)
 
 	r, err := cloud.Compute().Instances().Get(cloud.Project(), *e.Zone, *e.Name)
 	if err != nil {
@@ -76,8 +76,8 @@ func (e *Instance) Find(c *fi.Context) (*Instance, error) {
 	actual := &Instance{}
 	actual.Name = &r.Name
 	actual.Tags = append(actual.Tags, r.Tags.Items...)
-	actual.Zone = fi.String(lastComponent(r.Zone))
-	actual.MachineType = fi.String(lastComponent(r.MachineType))
+	actual.Zone = fi.PtrTo(lastComponent(r.Zone))
+	actual.MachineType = fi.PtrTo(lastComponent(r.MachineType))
 	actual.CanIPForward = &r.CanIpForward
 
 	if r.Scheduling != nil {
@@ -85,7 +85,7 @@ func (e *Instance) Find(c *fi.Context) (*Instance, error) {
 	}
 	if len(r.NetworkInterfaces) != 0 {
 		ni := r.NetworkInterfaces[0]
-		actual.Network = &Network{Name: fi.String(lastComponent(ni.Network))}
+		actual.Network = &Network{Name: fi.PtrTo(lastComponent(ni.Network))}
 		if len(ni.AccessConfigs) != 0 {
 			ac := ni.AccessConfigs[0]
 			if ac.NatIP != "" {
@@ -126,7 +126,7 @@ func (e *Instance) Find(c *fi.Context) (*Instance, error) {
 			if err != nil {
 				return nil, fmt.Errorf("error parsing source image URL: %v", err)
 			}
-			actual.Image = fi.String(image)
+			actual.Image = fi.PtrTo(image)
 		} else {
 			url, err := gce.ParseGoogleCloudURL(disk.Source)
 			if err != nil {
@@ -140,7 +140,7 @@ func (e *Instance) Find(c *fi.Context) (*Instance, error) {
 	if r.Metadata != nil {
 		actual.Metadata = make(map[string]fi.Resource)
 		for _, i := range r.Metadata.Items {
-			actual.Metadata[i.Key] = fi.NewStringResource(fi.StringValue(i.Value))
+			actual.Metadata[i.Key] = fi.NewStringResource(fi.ValueOf(i.Value))
 		}
 		actual.metadataFingerprint = r.Metadata.Fingerprint
 	}
@@ -148,8 +148,8 @@ func (e *Instance) Find(c *fi.Context) (*Instance, error) {
 	return actual, nil
 }
 
-func (e *Instance) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *Instance) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (_ *Instance) CheckChanges(a, e, changes *Instance) error {
@@ -189,14 +189,14 @@ func (e *Instance) mapToGCE(project string, ipAddressResolver func(*Address) (*s
 	zone := *e.Zone
 
 	var scheduling *compute.Scheduling
-	if fi.BoolValue(e.Preemptible) {
+	if fi.ValueOf(e.Preemptible) {
 		scheduling = &compute.Scheduling{
 			OnHostMaintenance: "TERMINATE",
 			Preemptible:       true,
 		}
 	} else {
 		scheduling = &compute.Scheduling{
-			AutomaticRestart: fi.Bool(true),
+			AutomaticRestart: fi.PtrTo(true),
 			// TODO: Migrate or terminate?
 			OnHostMaintenance: "MIGRATE",
 			Preemptible:       false,
@@ -263,7 +263,7 @@ func (e *Instance) mapToGCE(project string, ipAddressResolver func(*Address) (*s
 				scopes = append(scopes, s)
 			}
 			serviceAccounts = append(serviceAccounts, &compute.ServiceAccount{
-				Email:  fi.StringValue(e.ServiceAccount.Email),
+				Email:  fi.ValueOf(e.ServiceAccount.Email),
 				Scopes: scopes,
 			})
 		}
@@ -277,7 +277,7 @@ func (e *Instance) mapToGCE(project string, ipAddressResolver func(*Address) (*s
 		}
 		metadataItems = append(metadataItems, &compute.MetadataItems{
 			Key:   key,
-			Value: fi.String(v),
+			Value: fi.PtrTo(v),
 		})
 	}
 
@@ -485,7 +485,7 @@ func (_ *Instance) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *
 
 	if i.Scheduling != nil {
 		tf.Scheduling = &terraformScheduling{
-			AutomaticRestart:  fi.BoolValue(i.Scheduling.AutomaticRestart),
+			AutomaticRestart:  fi.ValueOf(i.Scheduling.AutomaticRestart),
 			OnHostMaintenance: i.Scheduling.OnHostMaintenance,
 			Preemptible:       i.Scheduling.Preemptible,
 		}
