@@ -96,10 +96,6 @@ func (e *Instance) GetDependencies(tasks map[string]fi.CloudupTask) []fi.Cloudup
 
 var _ fi.CompareWithID = &Instance{}
 
-func (e *Instance) WaitForStatusActive(t *openstack.OpenstackAPITarget) error {
-	return servers.WaitForStatus(t.Cloud.ComputeClient(), *e.ID, "ACTIVE", 120)
-}
-
 func (e *Instance) CompareWithID() *string {
 	return e.ID
 }
