@@ -87,8 +87,8 @@ func waitLoadbalancerActiveProvisioningStatus(client *gophercloud.ServiceClient,
 }
 
 // GetDependencies returns the dependencies of the Instance task
-func (e *LB) GetDependencies(tasks map[string]fi.Task) []fi.Task {
-	var deps []fi.Task
+func (e *LB) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
+	var deps []fi.CloudupTask
 	for _, task := range tasks {
 		if _, ok := task.(*Subnet); ok {
 			deps = append(deps, task)
@@ -119,17 +119,17 @@ func NewLBTaskFromCloud(cloud openstack.OpenstackCloud, lifecycle fi.Lifecycle,
 	}
 
 	actual := &LB{
-		ID:        fi.String(lb.ID),
-		Name:      fi.String(lb.Name),
+		ID:        fi.PtrTo(lb.ID),
+		Name:      fi.PtrTo(lb.Name),
 		Lifecycle: lifecycle,
-		PortID:    fi.String(lb.VipPortID),
-		Subnet:    fi.String(sub.Name),
-		VipSubnet: fi.String(lb.VipSubnetID),
-		Provider:  fi.String(lb.Provider),
+		PortID:    fi.PtrTo(lb.VipPortID),
+		Subnet:    fi.PtrTo(sub.Name),
+		VipSubnet: fi.PtrTo(lb.VipSubnetID),
+		Provider:  fi.PtrTo(lb.Provider),
 	}
 
 	if secGroup {
-		sg, err := getSecurityGroupByName(&SecurityGroup{Name: fi.String(lb.Name)}, osCloud)
+		sg, err := getSecurityGroupByName(&SecurityGroup{Name: fi.PtrTo(lb.Name)}, osCloud)
 		if err != nil {
 			return nil, err
 		}
@@ -144,17 +144,17 @@ func NewLBTaskFromCloud(cloud openstack.OpenstackCloud, lifecycle fi.Lifecycle,
 	return actual, nil
 }
 
-func (s *LB) Find(context *fi.Context) (*LB, error) {
+func (s *LB) Find(context *fi.CloudupContext) (*LB, error) {
 	if s.Name == nil {
 		return nil, nil
 	}
 
-	cloud := context.Cloud.(openstack.OpenstackCloud)
+	cloud := context.T.Cloud.(openstack.OpenstackCloud)
 	lbPage, err := loadbalancers.List(cloud.LoadBalancerClient(), loadbalancers.ListOpts{
-		Name: fi.StringValue(s.Name),
+		Name: fi.ValueOf(s.Name),
 	}).AllPages()
 	if err != nil {
-		return nil, fmt.Errorf("Failed to retrieve loadbalancers for name %s: %v", fi.StringValue(s.Name), err)
+		return nil, fmt.Errorf("Failed to retrieve loadbalancers for name %s: %v", fi.ValueOf(s.Name), err)
 	}
 	lbs, err := loadbalancers.ExtractLoadBalancers(lbPage)
 	if err != nil {
@@ -164,14 +164,14 @@ func (s *LB) Find(context *fi.Context) (*LB, error) {
 		return nil, nil
 	}
 	if len(lbs) > 1 {
-		return nil, fmt.Errorf("Multiple load balancers for name %s", fi.StringValue(s.Name))
+		return nil, fmt.Errorf("Multiple load balancers for name %s", fi.ValueOf(s.Name))
 	}
 
 	return NewLBTaskFromCloud(cloud, s.Lifecycle, &lbs[0], s)
 }
 
-func (s *LB) Run(context *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(s, context)
+func (s *LB) Run(context *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(s, context)
 }
 
 func (_ *LB) CheckChanges(a, e, changes *LB) error {
@@ -192,34 +192,34 @@ func (_ *LB) CheckChanges(a, e, changes *LB) error {
 
 func (_ *LB) RenderOpenstack(t *openstack.OpenstackAPITarget, a, e, changes *LB) error {
 	if a == nil {
-		klog.V(2).Infof("Creating LB with Name: %q", fi.StringValue(e.Name))
+		klog.V(2).Infof("Creating LB with Name: %q", fi.ValueOf(e.Name))
 
 		subnets, err := t.Cloud.ListSubnets(subnets.ListOpts{
-			Name: fi.StringValue(e.Subnet),
+			Name: fi.ValueOf(e.Subnet),
 		})
 		if err != nil {
-			return fmt.Errorf("Failed to retrieve subnet `%s` in loadbalancer creation: %v", fi.StringValue(e.Subnet), err)
+			return fmt.Errorf("Failed to retrieve subnet `%s` in loadbalancer creation: %v", fi.ValueOf(e.Subnet), err)
 		}
 		if len(subnets) != 1 {
-			return fmt.Errorf("Unexpected desired subnets for `%s`.  Expected 1, got %d", fi.StringValue(e.Subnet), len(subnets))
+			return fmt.Errorf("Unexpected desired subnets for `%s`.  Expected 1, got %d", fi.ValueOf(e.Subnet), len(subnets))
 		}
 
 		lbopts := loadbalancers.CreateOpts{
-			Name:        fi.StringValue(e.Name),
+			Name:        fi.ValueOf(e.Name),
 			VipSubnetID: subnets[0].ID,
 		}
 		lb, err := t.Cloud.CreateLB(lbopts)
 		if err != nil {
 			return fmt.Errorf("error creating LB: %v", err)
 		}
-		e.ID = fi.String(lb.ID)
-		e.PortID = fi.String(lb.VipPortID)
-		e.VipSubnet = fi.String(lb.VipSubnetID)
-		e.Provider = fi.String(lb.Provider)
+		e.ID = fi.PtrTo(lb.ID)
+		e.PortID = fi.PtrTo(lb.VipPortID)
+		e.VipSubnet = fi.PtrTo(lb.VipSubnetID)
+		e.Provider = fi.PtrTo(lb.Provider)
 
 		if e.SecurityGroup != nil {
 			opts := ports.UpdateOpts{
-				SecurityGroups: &[]string{fi.StringValue(e.SecurityGroup.ID)},
+				SecurityGroups: &[]string{fi.ValueOf(e.SecurityGroup.ID)},
 			}
 			_, err = ports.Update(t.Cloud.NetworkingClient(), lb.VipPortID, opts).Extract()
 			if err != nil {
@@ -229,20 +229,20 @@ func (_ *LB) RenderOpenstack(t *openstack.OpenstackAPITarget, a, e, changes *LB)
 		return nil
 	}
 	// We may have failed to update the security groups on the load balancer
-	port, err := t.Cloud.GetPort(fi.StringValue(a.PortID))
+	port, err := t.Cloud.GetPort(fi.ValueOf(a.PortID))
 	if err != nil {
-		return fmt.Errorf("Failed to get port with id %s: %v", fi.StringValue(a.PortID), err)
+		return fmt.Errorf("Failed to get port with id %s: %v", fi.ValueOf(a.PortID), err)
 	}
 	// Ensure the loadbalancer port has one security group and it is the one specified,
 	if e.SecurityGroup != nil &&
-		(len(port.SecurityGroups) < 1 || port.SecurityGroups[0] != fi.StringValue(e.SecurityGroup.ID)) {
+		(len(port.SecurityGroups) < 1 || port.SecurityGroups[0] != fi.ValueOf(e.SecurityGroup.ID)) {
 
 		opts := ports.UpdateOpts{
-			SecurityGroups: &[]string{fi.StringValue(e.SecurityGroup.ID)},
+			SecurityGroups: &[]string{fi.ValueOf(e.SecurityGroup.ID)},
 		}
-		_, err = ports.Update(t.Cloud.NetworkingClient(), fi.StringValue(a.PortID), opts).Extract()
+		_, err = ports.Update(t.Cloud.NetworkingClient(), fi.ValueOf(a.PortID), opts).Extract()
 		if err != nil {
-			return fmt.Errorf("Failed to update security group for port %s: %v", fi.StringValue(a.PortID), err)
+			return fmt.Errorf("Failed to update security group for port %s: %v", fi.ValueOf(a.PortID), err)
 		}
 		return nil
 	}
