@@ -54,6 +54,8 @@ func FindDistribution(rootfs string) (Distribution, error) {
 		return DistributionDebian10, nil
 	case "debian-11":
 		return DistributionDebian11, nil
+	case "debian-12":
+		return DistributionDebian12, nil
 	case "ubuntu-18.04":
 		return DistributionUbuntu1804, nil
 	case "ubuntu-20.04":
